Class: Azure::ARM::DevTestLabs::Disks

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/disks.rb

Overview

The DevTest Labs Client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ Disks

Creates and initializes a new instance of the Disks class.

Parameters:

  • client

    service class for accessing basic functionality.



17
18
19
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 17

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientDevTestLabsClient (readonly)

Returns reference to the DevTestLabsClient.

Returns:



22
23
24
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 22

def client
  @client
end

Instance Method Details

#attach(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers = nil) ⇒ Object

Attach and create the lease of the disk to the virtual machine. This operation can take a while to complete.

to attach. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • attach_disk_properties (AttachDiskProperties)

    Properties of the disk

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



349
350
351
352
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 349

def attach(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers = nil)
  response = attach_async(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers).value!
  nil
end

#attach_async(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers = nil) ⇒ Concurrent::Promise

to attach. will be added to the HTTP request.

response.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • attach_disk_properties (AttachDiskProperties)

    Properties of the disk

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Concurrent::Promise)

    promise which provides async access to http



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 367

def attach_async(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers = nil)
  # Send request
  promise = begin_attach_async(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#begin_attach(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers = nil) ⇒ Object

Attach and create the lease of the disk to the virtual machine. This operation can take a while to complete.

to attach. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • attach_disk_properties (AttachDiskProperties)

    Properties of the disk

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



657
658
659
660
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 657

def begin_attach(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers = nil)
  response = begin_attach_async(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers).value!
  nil
end

#begin_attach_async(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers = nil) ⇒ Concurrent::Promise

Attach and create the lease of the disk to the virtual machine. This operation can take a while to complete.

to attach. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • attach_disk_properties (AttachDiskProperties)

    Properties of the disk

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 696

def begin_attach_async(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'user_name is nil' if user_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'attach_disk_properties is nil' if attach_disk_properties.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = Azure::ARM::DevTestLabs::Models::AttachDiskProperties.mapper()
  request_content = @client.serialize(request_mapper,  attach_disk_properties)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/users/{userName}/disks/{name}/attach'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'userName' => user_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:post, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 202
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#begin_attach_with_http_info(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Attach and create the lease of the disk to the virtual machine. This operation can take a while to complete.

to attach. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • attach_disk_properties (AttachDiskProperties)

    Properties of the disk

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



677
678
679
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 677

def begin_attach_with_http_info(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers = nil)
  begin_attach_async(resource_group_name, lab_name, user_name, name, attach_disk_properties, custom_headers).value!
end

#begin_create_or_update(resource_group_name, lab_name, user_name, name, disk, custom_headers = nil) ⇒ Disk

Create or replace an existing disk. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • disk (Disk)

    A Disk.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Disk)

    operation results.



444
445
446
447
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 444

def begin_create_or_update(resource_group_name, lab_name, user_name, name, disk, custom_headers = nil)
  response = begin_create_or_update_async(resource_group_name, lab_name, user_name, name, disk, custom_headers).value!
  response.body unless response.nil?
end

#begin_create_or_update_async(resource_group_name, lab_name, user_name, name, disk, custom_headers = nil) ⇒ Concurrent::Promise

Create or replace an existing disk. This operation can take a while to complete.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • disk (Disk)

    A Disk.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 481

def begin_create_or_update_async(resource_group_name, lab_name, user_name, name, disk, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'user_name is nil' if user_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'disk is nil' if disk.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = Azure::ARM::DevTestLabs::Models::Disk.mapper()
  request_content = @client.serialize(request_mapper,  disk)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/users/{userName}/disks/{name}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'userName' => user_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:put, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 201
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::Disk.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end
    # Deserialize Response
    if status_code == 201
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::Disk.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#begin_create_or_update_with_http_info(resource_group_name, lab_name, user_name, name, disk, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Create or replace an existing disk. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • disk (Disk)

    A Disk.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



463
464
465
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 463

def begin_create_or_update_with_http_info(resource_group_name, lab_name, user_name, name, disk, custom_headers = nil)
  begin_create_or_update_async(resource_group_name, lab_name, user_name, name, disk, custom_headers).value!
end

#begin_delete(resource_group_name, lab_name, user_name, name, custom_headers = nil) ⇒ Object

Delete disk. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



566
567
568
569
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 566

def begin_delete(resource_group_name, lab_name, user_name, name, custom_headers = nil)
  response = begin_delete_async(resource_group_name, lab_name, user_name, name, custom_headers).value!
  nil
end

#begin_delete_async(resource_group_name, lab_name, user_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Delete disk. This operation can take a while to complete.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 599

def begin_delete_async(resource_group_name, lab_name, user_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'user_name is nil' if user_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/users/{userName}/disks/{name}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'userName' => user_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:delete, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 202 || status_code == 204
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#begin_delete_with_http_info(resource_group_name, lab_name, user_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Delete disk. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



583
584
585
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 583

def begin_delete_with_http_info(resource_group_name, lab_name, user_name, name, custom_headers = nil)
  begin_delete_async(resource_group_name, lab_name, user_name, name, custom_headers).value!
end

#begin_detach(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers = nil) ⇒ Object

Detach and break the lease of the disk attached to the virtual machine. This operation can take a while to complete.

to detach. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • detach_disk_properties (DetachDiskProperties)

    Properties of the disk

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



764
765
766
767
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 764

def begin_detach(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers = nil)
  response = begin_detach_async(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers).value!
  nil
end

#begin_detach_async(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers = nil) ⇒ Concurrent::Promise

Detach and break the lease of the disk attached to the virtual machine. This operation can take a while to complete.

to detach. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • detach_disk_properties (DetachDiskProperties)

    Properties of the disk

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 803

def begin_detach_async(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'user_name is nil' if user_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'detach_disk_properties is nil' if detach_disk_properties.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = Azure::ARM::DevTestLabs::Models::DetachDiskProperties.mapper()
  request_content = @client.serialize(request_mapper,  detach_disk_properties)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/users/{userName}/disks/{name}/detach'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'userName' => user_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:post, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 202
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#begin_detach_with_http_info(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Detach and break the lease of the disk attached to the virtual machine. This operation can take a while to complete.

to detach. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • detach_disk_properties (DetachDiskProperties)

    Properties of the disk

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



784
785
786
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 784

def begin_detach_with_http_info(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers = nil)
  begin_detach_async(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers).value!
end

#create_or_update(resource_group_name, lab_name, user_name, name, disk, custom_headers = nil) ⇒ Disk

Create or replace an existing disk. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • disk (Disk)

    A Disk.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Disk)

    operation results.



259
260
261
262
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 259

def create_or_update(resource_group_name, lab_name, user_name, name, disk, custom_headers = nil)
  response = create_or_update_async(resource_group_name, lab_name, user_name, name, disk, custom_headers).value!
  response.body unless response.nil?
end

#create_or_update_async(resource_group_name, lab_name, user_name, name, disk, custom_headers = nil) ⇒ Concurrent::Promise

will be added to the HTTP request.

response.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • disk (Disk)

    A Disk.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Concurrent::Promise)

    promise which provides async access to http



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 276

def create_or_update_async(resource_group_name, lab_name, user_name, name, disk, custom_headers = nil)
  # Send request
  promise = begin_create_or_update_async(resource_group_name, lab_name, user_name, name, disk, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
      result_mapper = Azure::ARM::DevTestLabs::Models::Disk.mapper()
      parsed_response = @client.deserialize(result_mapper, parsed_response)
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#delete(resource_group_name, lab_name, user_name, name, custom_headers = nil) ⇒ Object

Delete disk. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



304
305
306
307
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 304

def delete(resource_group_name, lab_name, user_name, name, custom_headers = nil)
  response = delete_async(resource_group_name, lab_name, user_name, name, custom_headers).value!
  nil
end

#delete_async(resource_group_name, lab_name, user_name, name, custom_headers = nil) ⇒ Concurrent::Promise

will be added to the HTTP request.

response.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Concurrent::Promise)

    promise which provides async access to http



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 320

def delete_async(resource_group_name, lab_name, user_name, name, custom_headers = nil)
  # Send request
  promise = begin_delete_async(resource_group_name, lab_name, user_name, name, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#detach(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers = nil) ⇒ Object

Detach and break the lease of the disk attached to the virtual machine. This operation can take a while to complete.

to detach. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • detach_disk_properties (DetachDiskProperties)

    Properties of the disk

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



396
397
398
399
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 396

def detach(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers = nil)
  response = detach_async(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers).value!
  nil
end

#detach_async(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers = nil) ⇒ Concurrent::Promise

to detach. will be added to the HTTP request.

response.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • detach_disk_properties (DetachDiskProperties)

    Properties of the disk

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Concurrent::Promise)

    promise which provides async access to http



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 414

def detach_async(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers = nil)
  # Send request
  promise = begin_detach_async(resource_group_name, lab_name, user_name, name, detach_disk_properties, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#get(resource_group_name, lab_name, user_name, name, expand = nil, custom_headers = nil) ⇒ Disk

Get disk.

‘properties($select=diskType)’ will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Disk)

    operation results.



154
155
156
157
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 154

def get(resource_group_name, lab_name, user_name, name, expand = nil, custom_headers = nil)
  response = get_async(resource_group_name, lab_name, user_name, name, expand, custom_headers).value!
  response.body unless response.nil?
end

#get_async(resource_group_name, lab_name, user_name, name, expand = nil, custom_headers = nil) ⇒ Concurrent::Promise

Get disk.

‘properties($select=diskType)’ to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 191

def get_async(resource_group_name, lab_name, user_name, name, expand = nil, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'user_name is nil' if user_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/users/{userName}/disks/{name}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'userName' => user_name,'name' => name},
      query_params: {'$expand' => expand,'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::Disk.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_with_http_info(resource_group_name, lab_name, user_name, name, expand = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Get disk.

‘properties($select=diskType)’ will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • name (String)

    The name of the disk.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



173
174
175
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 173

def get_with_http_info(resource_group_name, lab_name, user_name, name, expand = nil, custom_headers = nil)
  get_async(resource_group_name, lab_name, user_name, name, expand, custom_headers).value!
end

#list(resource_group_name, lab_name, user_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ Array<Disk>

List disks in a given user profile.

‘properties($select=diskType)’ operation. notation. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • filter (String) (defaults to: nil)

    The filter to apply to the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • orderby (String) (defaults to: nil)

    The ordering expression for the results, using OData

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Array<Disk>)

    operation results.



42
43
44
45
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 42

def list(resource_group_name, lab_name, user_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil)
  first_page = list_as_lazy(resource_group_name, lab_name, user_name, expand, filter, top, orderby, custom_headers)
  first_page.get_all_items
end

#list_as_lazy(resource_group_name, lab_name, user_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ ResponseWithContinuationDisk

List disks in a given user profile.

‘properties($select=diskType)’ operation. notation. will be added to the HTTP request.

the response.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • filter (String) (defaults to: nil)

    The filter to apply to the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • orderby (String) (defaults to: nil)

    The ordering expression for the results, using OData

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ResponseWithContinuationDisk)

    which provide lazy access to pages of



963
964
965
966
967
968
969
970
971
972
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 963

def list_as_lazy(resource_group_name, lab_name, user_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil)
  response = list_async(resource_group_name, lab_name, user_name, expand, filter, top, orderby, custom_headers).value!
  unless response.nil?
    page = response.body
    page.next_method = Proc.new do |next_page_link|
      list_next_async(next_page_link, custom_headers)
    end
    page
  end
end

#list_async(resource_group_name, lab_name, user_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ Concurrent::Promise

List disks in a given user profile.

‘properties($select=diskType)’ operation. notation. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • filter (String) (defaults to: nil)

    The filter to apply to the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • orderby (String) (defaults to: nil)

    The ordering expression for the results, using OData

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 87

def list_async(resource_group_name, lab_name, user_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'user_name is nil' if user_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/users/{userName}/disks'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'userName' => user_name},
      query_params: {'$expand' => expand,'$filter' => filter,'$top' => top,'$orderby' => orderby,'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::ResponseWithContinuationDisk.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationDisk

List disks in a given user profile.

to List operation. will be added to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ResponseWithContinuationDisk)

    operation results.



867
868
869
870
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 867

def list_next(next_page_link, custom_headers = nil)
  response = list_next_async(next_page_link, custom_headers).value!
  response.body unless response.nil?
end

#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise

List disks in a given user profile.

to List operation. to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 896

def list_next_async(next_page_link, custom_headers = nil)
  fail ArgumentError, 'next_page_link is nil' if next_page_link.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '{nextLink}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      skip_encoding_path_params: {'nextLink' => next_page_link},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::ResponseWithContinuationDisk.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List disks in a given user profile.

to List operation. will be added to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



882
883
884
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 882

def list_next_with_http_info(next_page_link, custom_headers = nil)
  list_next_async(next_page_link, custom_headers).value!
end

#list_with_http_info(resource_group_name, lab_name, user_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List disks in a given user profile.

‘properties($select=diskType)’ operation. notation. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • user_name (String)

    The name of the user profile.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • filter (String) (defaults to: nil)

    The filter to apply to the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • orderby (String) (defaults to: nil)

    The ordering expression for the results, using OData

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



65
66
67
# File 'lib/generated/azure_mgmt_devtestlabs/disks.rb', line 65

def list_with_http_info(resource_group_name, lab_name, user_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil)
  list_async(resource_group_name, lab_name, user_name, expand, filter, top, orderby, custom_headers).value!
end