Class: Azure::ARM::DevTestLabs::Models::Artifact

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/artifact.rb

Overview

An artifact.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#descriptionString

Returns The description of the artifact.

Returns:

  • (String)

    The description of the artifact.



19
20
21
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 19

def description
  @description
end

#file_pathString

Returns The file path of the artifact.

Returns:

  • (String)

    The file path of the artifact.



22
23
24
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 22

def file_path
  @file_path
end

#iconString

Returns The icon of the artifact.

Returns:

  • (String)

    The icon of the artifact.



25
26
27
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 25

def icon
  @icon
end

#idString

Returns The identifier of the resource.

Returns:

  • (String)

    The identifier of the resource.



34
35
36
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 34

def id
  @id
end

#locationString

Returns The location of the resource.

Returns:

  • (String)

    The location of the resource.



43
44
45
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 43

def location
  @location
end

#nameString

Returns The name of the resource.

Returns:

  • (String)

    The name of the resource.



37
38
39
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 37

def name
  @name
end

#parametersObject

Returns The parameters of the artifact.

Returns:

  • The parameters of the artifact.



31
32
33
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 31

def parameters
  @parameters
end

#tagsHash{String => String}

Returns The tags of the resource.

Returns:

  • (Hash{String => String})

    The tags of the resource.



46
47
48
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 46

def tags
  @tags
end

#target_os_typeString

Returns Gets or sets the type of the target os.

Returns:

  • (String)

    Gets or sets the type of the target os.



28
29
30
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 28

def target_os_type
  @target_os_type
end

#titleString

Returns The title of the artifact.

Returns:

  • (String)

    The title of the artifact.



16
17
18
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 16

def title
  @title
end

#typeString

Returns The type of the resource.

Returns:

  • (String)

    The type of the resource.



40
41
42
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 40

def type
  @type
end

Class Method Details

.mapperObject

Mapper for Artifact class as Ruby Hash. This will be used for serialization/deserialization.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact.rb', line 53

def self.mapper()
  {
    required: false,
    serialized_name: 'Artifact',
    type: {
      name: 'Composite',
      class_name: 'Artifact',
      model_properties: {
        title: {
          required: false,
          serialized_name: 'properties.title',
          type: {
            name: 'String'
          }
        },
        description: {
          required: false,
          serialized_name: 'properties.description',
          type: {
            name: 'String'
          }
        },
        file_path: {
          required: false,
          serialized_name: 'properties.filePath',
          type: {
            name: 'String'
          }
        },
        icon: {
          required: false,
          serialized_name: 'properties.icon',
          type: {
            name: 'String'
          }
        },
        target_os_type: {
          required: false,
          serialized_name: 'properties.targetOsType',
          type: {
            name: 'String'
          }
        },
        parameters: {
          required: false,
          serialized_name: 'properties.parameters',
          type: {
            name: 'Object'
          }
        },
        id: {
          required: false,
          serialized_name: 'id',
          type: {
            name: 'String'
          }
        },
        name: {
          required: false,
          serialized_name: 'name',
          type: {
            name: 'String'
          }
        },
        type: {
          required: false,
          serialized_name: 'type',
          type: {
            name: 'String'
          }
        },
        location: {
          required: false,
          serialized_name: 'location',
          type: {
            name: 'String'
          }
        },
        tags: {
          required: false,
          serialized_name: 'tags',
          type: {
            name: 'Dictionary',
            value: {
                required: false,
                serialized_name: 'StringElementType',
                type: {
                  name: 'String'
                }
            }
          }
        }
      }
    }
  }
end