Class: Azure::ARM::DevTestLabs::Models::ArtifactInstallPropertiesFragment

Inherits:
Object
  • Object
show all
Includes:
MsRest::JSONable, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/artifact_install_properties_fragment.rb

Overview

Properties of an artifact.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#artifact_idString

Returns The artifact’s identifier.

Returns:

  • (String)

    The artifact’s identifier.



17
18
19
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact_install_properties_fragment.rb', line 17

def artifact_id
  @artifact_id
end

#deployment_status_messageString

Returns The status message from the deployment.

Returns:

  • (String)

    The status message from the deployment.



27
28
29
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact_install_properties_fragment.rb', line 27

def deployment_status_message
  @deployment_status_message
end

#install_timeDateTime

virtual machine.

Returns:

  • (DateTime)

    The time that the artifact starts to install on the



34
35
36
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact_install_properties_fragment.rb', line 34

def install_time
  @install_time
end

#parametersArray<ArtifactParameterPropertiesFragment>

the artifact.

Returns:



21
22
23
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact_install_properties_fragment.rb', line 21

def parameters
  @parameters
end

#statusString

Returns The status of the artifact.

Returns:

  • (String)

    The status of the artifact.



24
25
26
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact_install_properties_fragment.rb', line 24

def status
  @status
end

#vm_extension_status_messageString

Returns The status message from the virtual machine extension.

Returns:

  • (String)

    The status message from the virtual machine extension.



30
31
32
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact_install_properties_fragment.rb', line 30

def vm_extension_status_message
  @vm_extension_status_message
end

Class Method Details

.mapperObject

Mapper for ArtifactInstallPropertiesFragment class as Ruby Hash. This will be used for serialization/deserialization.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/generated/azure_mgmt_devtestlabs/models/artifact_install_properties_fragment.rb', line 41

def self.mapper()
  {
    required: false,
    serialized_name: 'ArtifactInstallPropertiesFragment',
    type: {
      name: 'Composite',
      class_name: 'ArtifactInstallPropertiesFragment',
      model_properties: {
        artifact_id: {
          required: false,
          serialized_name: 'artifactId',
          type: {
            name: 'String'
          }
        },
        parameters: {
          required: false,
          serialized_name: 'parameters',
          type: {
            name: 'Sequence',
            element: {
                required: false,
                serialized_name: 'ArtifactParameterPropertiesFragmentElementType',
                type: {
                  name: 'Composite',
                  class_name: 'ArtifactParameterPropertiesFragment'
                }
            }
          }
        },
        status: {
          required: false,
          serialized_name: 'status',
          type: {
            name: 'String'
          }
        },
        deployment_status_message: {
          required: false,
          serialized_name: 'deploymentStatusMessage',
          type: {
            name: 'String'
          }
        },
        vm_extension_status_message: {
          required: false,
          serialized_name: 'vmExtensionStatusMessage',
          type: {
            name: 'String'
          }
        },
        install_time: {
          required: false,
          serialized_name: 'installTime',
          type: {
            name: 'DateTime'
          }
        }
      }
    }
  }
end