Class: Azure::ARM::DevTestLabs::Models::AttachNewDataDiskOptions

Inherits:
Object
  • Object
show all
Includes:
MsRest::JSONable, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/attach_new_data_disk_options.rb

Overview

Properties to attach new disk to the Virtual Machine.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#disk_nameString

Returns The name of the disk to be attached.

Returns:

  • (String)

    The name of the disk to be attached.



20
21
22
# File 'lib/generated/azure_mgmt_devtestlabs/models/attach_new_data_disk_options.rb', line 20

def disk_name
  @disk_name
end

#disk_size_gi_bInteger

Returns Size of the disk to be attached in GibiBytes.

Returns:

  • (Integer)

    Size of the disk to be attached in GibiBytes.



17
18
19
# File 'lib/generated/azure_mgmt_devtestlabs/models/attach_new_data_disk_options.rb', line 17

def disk_size_gi_b
  @disk_size_gi_b
end

#disk_typeStorageType

Premium). Possible values include: ‘Standard’, ‘Premium’

Returns:

  • (StorageType)

    The storage type for the disk (i.e. Standard,



24
25
26
# File 'lib/generated/azure_mgmt_devtestlabs/models/attach_new_data_disk_options.rb', line 24

def disk_type
  @disk_type
end

Class Method Details

.mapperObject

Mapper for AttachNewDataDiskOptions class as Ruby Hash. This will be used for serialization/deserialization.



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/generated/azure_mgmt_devtestlabs/models/attach_new_data_disk_options.rb', line 31

def self.mapper()
  {
    required: false,
    serialized_name: 'AttachNewDataDiskOptions',
    type: {
      name: 'Composite',
      class_name: 'AttachNewDataDiskOptions',
      model_properties: {
        disk_size_gi_b: {
          required: false,
          serialized_name: 'diskSizeGiB',
          type: {
            name: 'Number'
          }
        },
        disk_name: {
          required: false,
          serialized_name: 'diskName',
          type: {
            name: 'String'
          }
        },
        disk_type: {
          required: false,
          serialized_name: 'diskType',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end