Class: Azure::ARM::DevTestLabs::Models::CustomImage

Inherits:
MsRestAzure::Resource
  • Object
show all
Includes:
MsRest::JSONable, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/custom_image.rb

Overview

A custom image.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#authorString

Returns The author of the custom image.

Returns:

  • (String)

    The author of the custom image.



28
29
30
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image.rb', line 28

def author
  @author
end

#creation_dateDateTime

Returns The creation date of the custom image.

Returns:

  • (DateTime)

    The creation date of the custom image.



31
32
33
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image.rb', line 31

def creation_date
  @creation_date
end

#descriptionString

Returns The description of the custom image.

Returns:

  • (String)

    The description of the custom image.



25
26
27
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image.rb', line 25

def description
  @description
end

#managed_image_idString

Returns The Managed Image Id backing the custom image.

Returns:

  • (String)

    The Managed Image Id backing the custom image.



34
35
36
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image.rb', line 34

def managed_image_id
  @managed_image_id
end

#provisioning_stateString

Returns The provisioning status of the resource.

Returns:

  • (String)

    The provisioning status of the resource.



37
38
39
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image.rb', line 37

def provisioning_state
  @provisioning_state
end

#unique_identifierString

Returns The unique immutable identifier of a resource (Guid).

Returns:

  • (String)

    The unique immutable identifier of a resource (Guid).



40
41
42
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image.rb', line 40

def unique_identifier
  @unique_identifier
end

#vhdCustomImagePropertiesCustom

to be created.

Returns:



22
23
24
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image.rb', line 22

def vhd
  @vhd
end

#vmCustomImagePropertiesFromVm

the image is to be created.

Returns:



18
19
20
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image.rb', line 18

def vm
  @vm
end

Class Method Details

.mapperObject

Mapper for CustomImage class as Ruby Hash. This will be used for serialization/deserialization.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image.rb', line 47

def self.mapper()
  {
    required: false,
    serialized_name: 'CustomImage',
    type: {
      name: 'Composite',
      class_name: 'CustomImage',
      model_properties: {
        id: {
          required: false,
          read_only: true,
          serialized_name: 'id',
          type: {
            name: 'String'
          }
        },
        name: {
          required: false,
          read_only: true,
          serialized_name: 'name',
          type: {
            name: 'String'
          }
        },
        type: {
          required: false,
          read_only: true,
          serialized_name: 'type',
          type: {
            name: 'String'
          }
        },
        location: {
          required: false,
          serialized_name: 'location',
          type: {
            name: 'String'
          }
        },
        tags: {
          required: false,
          serialized_name: 'tags',
          type: {
            name: 'Dictionary',
            value: {
                required: false,
                serialized_name: 'StringElementType',
                type: {
                  name: 'String'
                }
            }
          }
        },
        vm: {
          required: false,
          serialized_name: 'properties.vm',
          type: {
            name: 'Composite',
            class_name: 'CustomImagePropertiesFromVm'
          }
        },
        vhd: {
          required: false,
          serialized_name: 'properties.vhd',
          type: {
            name: 'Composite',
            class_name: 'CustomImagePropertiesCustom'
          }
        },
        description: {
          required: false,
          serialized_name: 'properties.description',
          type: {
            name: 'String'
          }
        },
        author: {
          required: false,
          serialized_name: 'properties.author',
          type: {
            name: 'String'
          }
        },
        creation_date: {
          required: false,
          read_only: true,
          serialized_name: 'properties.creationDate',
          type: {
            name: 'DateTime'
          }
        },
        managed_image_id: {
          required: false,
          serialized_name: 'properties.managedImageId',
          type: {
            name: 'String'
          }
        },
        provisioning_state: {
          required: false,
          serialized_name: 'properties.provisioningState',
          type: {
            name: 'String'
          }
        },
        unique_identifier: {
          required: false,
          serialized_name: 'properties.uniqueIdentifier',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end