Class: Azure::ARM::DevTestLabs::Models::DataDiskProperties

Inherits:
Object
  • Object
show all
Includes:
MsRest::JSONable, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/data_disk_properties.rb

Overview

Request body for adding a new or existing data disk to a virtual machine.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#attach_new_data_disk_optionsAttachNewDataDiskOptions

disk to the virtual machine.

Returns:



18
19
20
# File 'lib/generated/azure_mgmt_devtestlabs/models/data_disk_properties.rb', line 18

def attach_new_data_disk_options
  @attach_new_data_disk_options
end

#existing_lab_disk_idString

virtual machine.

Returns:

  • (String)

    Specifies the existing lab disk id to attach to



22
23
24
# File 'lib/generated/azure_mgmt_devtestlabs/models/data_disk_properties.rb', line 22

def existing_lab_disk_id
  @existing_lab_disk_id
end

#host_cachingHostCachingOptions

ReadOnly, ReadWrite). Possible values include: ‘None’, ‘ReadOnly’, ‘ReadWrite’

Returns:



27
28
29
# File 'lib/generated/azure_mgmt_devtestlabs/models/data_disk_properties.rb', line 27

def host_caching
  @host_caching
end

Class Method Details

.mapperObject

Mapper for DataDiskProperties class as Ruby Hash. This will be used for serialization/deserialization.



34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/generated/azure_mgmt_devtestlabs/models/data_disk_properties.rb', line 34

def self.mapper()
  {
    required: false,
    serialized_name: 'DataDiskProperties',
    type: {
      name: 'Composite',
      class_name: 'DataDiskProperties',
      model_properties: {
        attach_new_data_disk_options: {
          required: false,
          serialized_name: 'attachNewDataDiskOptions',
          type: {
            name: 'Composite',
            class_name: 'AttachNewDataDiskOptions'
          }
        },
        existing_lab_disk_id: {
          required: false,
          serialized_name: 'existingLabDiskId',
          type: {
            name: 'String'
          }
        },
        host_caching: {
          required: false,
          serialized_name: 'hostCaching',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end