Class: Azure::ARM::DevTestLabs::Models::ExportResourceUsageParameters
- Inherits:
-
Object
- Object
- Azure::ARM::DevTestLabs::Models::ExportResourceUsageParameters
- Includes:
- MsRest::JSONable, MsRestAzure
- Defined in:
- lib/generated/azure_mgmt_devtestlabs/models/export_resource_usage_parameters.rb
Overview
The parameters of the export operation.
Instance Attribute Summary collapse
-
#blob_storage_absolute_sas_uri ⇒ String
permission to the container which the usage data needs to be uploaded to.
-
#usage_start_date ⇒ DateTime
will be reported since the beginning of data collection.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for ExportResourceUsageParameters class as Ruby Hash.
Instance Attribute Details
#blob_storage_absolute_sas_uri ⇒ String
permission to the container which the usage data needs to be uploaded to.
19 20 21 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/export_resource_usage_parameters.rb', line 19 def blob_storage_absolute_sas_uri @blob_storage_absolute_sas_uri end |
#usage_start_date ⇒ DateTime
will be reported since the beginning of data collection.
23 24 25 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/export_resource_usage_parameters.rb', line 23 def usage_start_date @usage_start_date end |
Class Method Details
.mapper ⇒ Object
Mapper for ExportResourceUsageParameters class as Ruby Hash. This will be used for serialization/deserialization.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/export_resource_usage_parameters.rb', line 30 def self.mapper() { required: false, serialized_name: 'ExportResourceUsageParameters', type: { name: 'Composite', class_name: 'ExportResourceUsageParameters', model_properties: { blob_storage_absolute_sas_uri: { required: false, serialized_name: 'blobStorageAbsoluteSasUri', type: { name: 'String' } }, usage_start_date: { required: false, serialized_name: 'usageStartDate', type: { name: 'DateTime' } } } } } end |