Class: Azure::ARM::DevTestLabs::Models::LabVirtualMachineFragment
- Inherits:
-
MsRestAzure::Resource
- Object
- MsRestAzure::Resource
- Azure::ARM::DevTestLabs::Models::LabVirtualMachineFragment
- Includes:
- MsRest::JSONable, MsRestAzure
- Defined in:
- lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb
Overview
A virtual machine.
Instance Attribute Summary collapse
-
#allow_claim ⇒ Boolean
the virtual machine.
-
#applicable_schedule ⇒ ApplicableScheduleFragment
virtual machine.
-
#artifact_deployment_status ⇒ ArtifactDeploymentStatusPropertiesFragment
deployment status for the virtual machine.
-
#artifacts ⇒ Array<ArtifactInstallPropertiesFragment>
installed on the virtual machine.
-
#compute_vm ⇒ ComputeVmPropertiesFragment
properties.
-
#created_by_user ⇒ String
The email address of creator of the virtual machine.
-
#created_by_user_id ⇒ String
machine.
-
#created_date ⇒ DateTime
The creation date of the virtual machine.
-
#custom_image_id ⇒ String
The custom image identifier of the virtual machine.
-
#disallow_public_ip_address ⇒ Boolean
created without a public IP address.
-
#environment_id ⇒ String
virtual machine, if any.
-
#expiration_date ⇒ DateTime
The expiration date for VM.
-
#fqdn ⇒ String
machine.
-
#gallery_image_reference ⇒ GalleryImageReferenceFragment
image reference of the virtual machine.
-
#is_authentication_with_ssh_key ⇒ Boolean
key for authentication.
-
#lab_subnet_name ⇒ String
The lab subnet name of the virtual machine.
-
#lab_virtual_network_id ⇒ String
machine.
-
#network_interface ⇒ NetworkInterfacePropertiesFragment
properties.
-
#notes ⇒ String
The notes of the virtual machine.
-
#os_type ⇒ String
The OS type of the virtual machine.
-
#owner_object_id ⇒ String
machine.
-
#owner_user_principal_name ⇒ String
The user principal name of the virtual machine owner.
-
#password ⇒ String
The password of the virtual machine administrator.
-
#provisioning_state ⇒ String
The provisioning status of the resource.
-
#size ⇒ String
The size of the virtual machine.
-
#ssh_key ⇒ String
The SSH key of the virtual machine administrator.
-
#storage_type ⇒ String
Standard, Premium).
-
#unique_identifier ⇒ String
The unique immutable identifier of a resource (Guid).
-
#user_name ⇒ String
The user name of the virtual machine.
-
#virtual_machine_creation_source ⇒ VirtualMachineCreationSource
virtual machine.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for LabVirtualMachineFragment class as Ruby Hash.
Instance Attribute Details
#allow_claim ⇒ Boolean
the virtual machine
102 103 104 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 102 def allow_claim @allow_claim end |
#applicable_schedule ⇒ ApplicableScheduleFragment
virtual machine.
95 96 97 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 95 def applicable_schedule @applicable_schedule end |
#artifact_deployment_status ⇒ ArtifactDeploymentStatusPropertiesFragment
deployment status for the virtual machine.
79 80 81 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 79 def artifact_deployment_status @artifact_deployment_status end |
#artifacts ⇒ Array<ArtifactInstallPropertiesFragment>
installed on the virtual machine.
75 76 77 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 75 def artifacts @artifacts end |
#compute_vm ⇒ ComputeVmPropertiesFragment
properties.
87 88 89 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 87 def compute_vm @compute_vm end |
#created_by_user ⇒ String
Returns The email address of creator of the virtual machine.
31 32 33 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 31 def created_by_user @created_by_user end |
#created_by_user_id ⇒ String
machine.
28 29 30 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 28 def created_by_user_id @created_by_user_id end |
#created_date ⇒ DateTime
Returns The creation date of the virtual machine.
34 35 36 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 34 def created_date @created_date end |
#custom_image_id ⇒ String
Returns The custom image identifier of the virtual machine.
37 38 39 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 37 def custom_image_id @custom_image_id end |
#disallow_public_ip_address ⇒ Boolean
created without a public IP address.
71 72 73 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 71 def disallow_public_ip_address @disallow_public_ip_address end |
#environment_id ⇒ String
virtual machine, if any.
115 116 117 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 115 def environment_id @environment_id end |
#expiration_date ⇒ DateTime
Returns The expiration date for VM.
98 99 100 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 98 def expiration_date @expiration_date end |
#fqdn ⇒ String
machine.
60 61 62 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 60 def fqdn @fqdn end |
#gallery_image_reference ⇒ GalleryImageReferenceFragment
image reference of the virtual machine.
83 84 85 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 83 def gallery_image_reference @gallery_image_reference end |
#is_authentication_with_ssh_key ⇒ Boolean
key for authentication.
56 57 58 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 56 def is_authentication_with_ssh_key @is_authentication_with_ssh_key end |
#lab_subnet_name ⇒ String
Returns The lab subnet name of the virtual machine.
63 64 65 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 63 def lab_subnet_name @lab_subnet_name end |
#lab_virtual_network_id ⇒ String
machine.
67 68 69 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 67 def lab_virtual_network_id @lab_virtual_network_id end |
#network_interface ⇒ NetworkInterfacePropertiesFragment
properties.
91 92 93 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 91 def network_interface @network_interface end |
#notes ⇒ String
Returns The notes of the virtual machine.
17 18 19 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 17 def notes @notes end |
#os_type ⇒ String
Returns The OS type of the virtual machine.
40 41 42 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 40 def os_type @os_type end |
#owner_object_id ⇒ String
machine.
21 22 23 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 21 def owner_object_id @owner_object_id end |
#owner_user_principal_name ⇒ String
Returns The user principal name of the virtual machine owner.
24 25 26 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 24 def owner_user_principal_name @owner_user_principal_name end |
#password ⇒ String
Returns The password of the virtual machine administrator.
49 50 51 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 49 def password @password end |
#provisioning_state ⇒ String
Returns The provisioning status of the resource.
118 119 120 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 118 def provisioning_state @provisioning_state end |
#size ⇒ String
Returns The size of the virtual machine.
43 44 45 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 43 def size @size end |
#ssh_key ⇒ String
Returns The SSH key of the virtual machine administrator.
52 53 54 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 52 def ssh_key @ssh_key end |
#storage_type ⇒ String
Standard, Premium).
106 107 108 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 106 def storage_type @storage_type end |
#unique_identifier ⇒ String
Returns The unique immutable identifier of a resource (Guid).
121 122 123 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 121 def unique_identifier @unique_identifier end |
#user_name ⇒ String
Returns The user name of the virtual machine.
46 47 48 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 46 def user_name @user_name end |
#virtual_machine_creation_source ⇒ VirtualMachineCreationSource
virtual machine. Output property only. Possible values include: ‘FromCustomImage’, ‘FromGalleryImage’
111 112 113 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 111 def virtual_machine_creation_source @virtual_machine_creation_source end |
Class Method Details
.mapper ⇒ Object
Mapper for LabVirtualMachineFragment class as Ruby Hash. This will be used for serialization/deserialization.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine_fragment.rb', line 128 def self.mapper() { required: false, serialized_name: 'LabVirtualMachineFragment', type: { name: 'Composite', class_name: 'LabVirtualMachineFragment', model_properties: { id: { required: false, read_only: true, serialized_name: 'id', type: { name: 'String' } }, name: { required: false, read_only: true, serialized_name: 'name', type: { name: 'String' } }, type: { required: false, read_only: true, serialized_name: 'type', type: { name: 'String' } }, location: { required: false, serialized_name: 'location', type: { name: 'String' } }, tags: { required: false, serialized_name: 'tags', type: { name: 'Dictionary', value: { required: false, serialized_name: 'StringElementType', type: { name: 'String' } } } }, notes: { required: false, serialized_name: 'properties.notes', type: { name: 'String' } }, owner_object_id: { required: false, serialized_name: 'properties.ownerObjectId', type: { name: 'String' } }, owner_user_principal_name: { required: false, serialized_name: 'properties.ownerUserPrincipalName', type: { name: 'String' } }, created_by_user_id: { required: false, serialized_name: 'properties.createdByUserId', type: { name: 'String' } }, created_by_user: { required: false, serialized_name: 'properties.createdByUser', type: { name: 'String' } }, created_date: { required: false, serialized_name: 'properties.createdDate', type: { name: 'DateTime' } }, custom_image_id: { required: false, serialized_name: 'properties.customImageId', type: { name: 'String' } }, os_type: { required: false, serialized_name: 'properties.osType', type: { name: 'String' } }, size: { required: false, serialized_name: 'properties.size', type: { name: 'String' } }, user_name: { required: false, serialized_name: 'properties.userName', type: { name: 'String' } }, password: { required: false, serialized_name: 'properties.password', type: { name: 'String' } }, ssh_key: { required: false, serialized_name: 'properties.sshKey', type: { name: 'String' } }, is_authentication_with_ssh_key: { required: false, serialized_name: 'properties.isAuthenticationWithSshKey', type: { name: 'Boolean' } }, fqdn: { required: false, serialized_name: 'properties.fqdn', type: { name: 'String' } }, lab_subnet_name: { required: false, serialized_name: 'properties.labSubnetName', type: { name: 'String' } }, lab_virtual_network_id: { required: false, serialized_name: 'properties.labVirtualNetworkId', type: { name: 'String' } }, disallow_public_ip_address: { required: false, serialized_name: 'properties.disallowPublicIpAddress', type: { name: 'Boolean' } }, artifacts: { required: false, serialized_name: 'properties.artifacts', type: { name: 'Sequence', element: { required: false, serialized_name: 'ArtifactInstallPropertiesFragmentElementType', type: { name: 'Composite', class_name: 'ArtifactInstallPropertiesFragment' } } } }, artifact_deployment_status: { required: false, serialized_name: 'properties.artifactDeploymentStatus', type: { name: 'Composite', class_name: 'ArtifactDeploymentStatusPropertiesFragment' } }, gallery_image_reference: { required: false, serialized_name: 'properties.galleryImageReference', type: { name: 'Composite', class_name: 'GalleryImageReferenceFragment' } }, compute_vm: { required: false, serialized_name: 'properties.computeVm', type: { name: 'Composite', class_name: 'ComputeVmPropertiesFragment' } }, network_interface: { required: false, serialized_name: 'properties.networkInterface', type: { name: 'Composite', class_name: 'NetworkInterfacePropertiesFragment' } }, applicable_schedule: { required: false, serialized_name: 'properties.applicableSchedule', type: { name: 'Composite', class_name: 'ApplicableScheduleFragment' } }, expiration_date: { required: false, serialized_name: 'properties.expirationDate', type: { name: 'DateTime' } }, allow_claim: { required: false, serialized_name: 'properties.allowClaim', type: { name: 'Boolean' } }, storage_type: { required: false, serialized_name: 'properties.storageType', type: { name: 'String' } }, virtual_machine_creation_source: { required: false, serialized_name: 'properties.virtualMachineCreationSource', type: { name: 'String' } }, environment_id: { required: false, serialized_name: 'properties.environmentId', type: { name: 'String' } }, provisioning_state: { required: false, serialized_name: 'properties.provisioningState', type: { name: 'String' } }, unique_identifier: { required: false, serialized_name: 'properties.uniqueIdentifier', type: { name: 'String' } } } } } end |