Class: Azure::ARM::DevTestLabs::Models::NetworkInterfacePropertiesFragment

Inherits:
Object
  • Object
show all
Includes:
MsRest::JSONable, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb

Overview

Properties of a network interface.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#dns_nameString

Returns The DNS name.

Returns:

  • (String)

    The DNS name.



32
33
34
# File 'lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb', line 32

def dns_name
  @dns_name
end

#private_ip_addressString

Returns The private IP address.

Returns:

  • (String)

    The private IP address.



29
30
31
# File 'lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb', line 29

def private_ip_address
  @private_ip_address
end

#public_ip_addressString

Returns The public IP address.

Returns:

  • (String)

    The public IP address.



26
27
28
# File 'lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb', line 26

def public_ip_address
  @public_ip_address
end

#public_ip_address_idString

Returns The resource ID of the public IP address.

Returns:

  • (String)

    The resource ID of the public IP address.



23
24
25
# File 'lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb', line 23

def public_ip_address_id
  @public_ip_address_id
end

#rdp_authorityString

IP address followed by the service port number for RDP (Remote Desktop Protocol).

Returns:

  • (String)

    The RdpAuthority property is a server DNS host name or



37
38
39
# File 'lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb', line 37

def rdp_authority
  @rdp_authority
end

#shared_public_ip_address_configurationSharedPublicIpAddressConfigurationFragment

for sharing a public IP address across multiple virtual machines.

Returns:



45
46
47
# File 'lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb', line 45

def shared_public_ip_address_configuration
  @shared_public_ip_address_configuration
end

#ssh_authorityString

IP address followed by the service port number for SSH.

Returns:

  • (String)

    The SshAuthority property is a server DNS host name or



41
42
43
# File 'lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb', line 41

def ssh_authority
  @ssh_authority
end

#subnet_idString

Returns The resource ID of the sub net.

Returns:

  • (String)

    The resource ID of the sub net.



20
21
22
# File 'lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb', line 20

def subnet_id
  @subnet_id
end

#virtual_network_idString

Returns The resource ID of the virtual network.

Returns:

  • (String)

    The resource ID of the virtual network.



17
18
19
# File 'lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb', line 17

def virtual_network_id
  @virtual_network_id
end

Class Method Details

.mapperObject

Mapper for NetworkInterfacePropertiesFragment class as Ruby Hash. This will be used for serialization/deserialization.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/generated/azure_mgmt_devtestlabs/models/network_interface_properties_fragment.rb', line 52

def self.mapper()
  {
    required: false,
    serialized_name: 'NetworkInterfacePropertiesFragment',
    type: {
      name: 'Composite',
      class_name: 'NetworkInterfacePropertiesFragment',
      model_properties: {
        virtual_network_id: {
          required: false,
          serialized_name: 'virtualNetworkId',
          type: {
            name: 'String'
          }
        },
        subnet_id: {
          required: false,
          serialized_name: 'subnetId',
          type: {
            name: 'String'
          }
        },
        public_ip_address_id: {
          required: false,
          serialized_name: 'publicIpAddressId',
          type: {
            name: 'String'
          }
        },
        public_ip_address: {
          required: false,
          serialized_name: 'publicIpAddress',
          type: {
            name: 'String'
          }
        },
        private_ip_address: {
          required: false,
          serialized_name: 'privateIpAddress',
          type: {
            name: 'String'
          }
        },
        dns_name: {
          required: false,
          serialized_name: 'dnsName',
          type: {
            name: 'String'
          }
        },
        rdp_authority: {
          required: false,
          serialized_name: 'rdpAuthority',
          type: {
            name: 'String'
          }
        },
        ssh_authority: {
          required: false,
          serialized_name: 'sshAuthority',
          type: {
            name: 'String'
          }
        },
        shared_public_ip_address_configuration: {
          required: false,
          serialized_name: 'sharedPublicIpAddressConfiguration',
          type: {
            name: 'Composite',
            class_name: 'SharedPublicIpAddressConfigurationFragment'
          }
        }
      }
    }
  }
end