Class: Azure::ARM::DevTestLabs::Models::NotificationChannel

Inherits:
MsRestAzure::Resource
  • Object
show all
Includes:
MsRest::JSONable, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/notification_channel.rb

Overview

A notification.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#created_dateDateTime

Returns The creation date of the notification channel.

Returns:

  • (DateTime)

    The creation date of the notification channel.



27
28
29
# File 'lib/generated/azure_mgmt_devtestlabs/models/notification_channel.rb', line 27

def created_date
  @created_date
end

#descriptionString

Returns Description of notification.

Returns:

  • (String)

    Description of notification.



20
21
22
# File 'lib/generated/azure_mgmt_devtestlabs/models/notification_channel.rb', line 20

def description
  @description
end

#eventsArray<Event>

enabled.

Returns:

  • (Array<Event>)

    The list of event for which this notification is



24
25
26
# File 'lib/generated/azure_mgmt_devtestlabs/models/notification_channel.rb', line 24

def events
  @events
end

#provisioning_stateString

Returns The provisioning status of the resource.

Returns:

  • (String)

    The provisioning status of the resource.



30
31
32
# File 'lib/generated/azure_mgmt_devtestlabs/models/notification_channel.rb', line 30

def provisioning_state
  @provisioning_state
end

#unique_identifierString

Returns The unique immutable identifier of a resource (Guid).

Returns:

  • (String)

    The unique immutable identifier of a resource (Guid).



33
34
35
# File 'lib/generated/azure_mgmt_devtestlabs/models/notification_channel.rb', line 33

def unique_identifier
  @unique_identifier
end

#web_hook_urlString

Returns The webhook URL to send notifications to.

Returns:

  • (String)

    The webhook URL to send notifications to.



17
18
19
# File 'lib/generated/azure_mgmt_devtestlabs/models/notification_channel.rb', line 17

def web_hook_url
  @web_hook_url
end

Class Method Details

.mapperObject

Mapper for NotificationChannel class as Ruby Hash. This will be used for serialization/deserialization.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/generated/azure_mgmt_devtestlabs/models/notification_channel.rb', line 40

def self.mapper()
  {
    required: false,
    serialized_name: 'NotificationChannel',
    type: {
      name: 'Composite',
      class_name: 'NotificationChannel',
      model_properties: {
        id: {
          required: false,
          read_only: true,
          serialized_name: 'id',
          type: {
            name: 'String'
          }
        },
        name: {
          required: false,
          read_only: true,
          serialized_name: 'name',
          type: {
            name: 'String'
          }
        },
        type: {
          required: false,
          read_only: true,
          serialized_name: 'type',
          type: {
            name: 'String'
          }
        },
        location: {
          required: false,
          serialized_name: 'location',
          type: {
            name: 'String'
          }
        },
        tags: {
          required: false,
          serialized_name: 'tags',
          type: {
            name: 'Dictionary',
            value: {
                required: false,
                serialized_name: 'StringElementType',
                type: {
                  name: 'String'
                }
            }
          }
        },
        web_hook_url: {
          required: false,
          serialized_name: 'properties.webHookUrl',
          type: {
            name: 'String'
          }
        },
        description: {
          required: false,
          serialized_name: 'properties.description',
          type: {
            name: 'String'
          }
        },
        events: {
          required: false,
          serialized_name: 'properties.events',
          type: {
            name: 'Sequence',
            element: {
                required: false,
                serialized_name: 'EventElementType',
                type: {
                  name: 'Composite',
                  class_name: 'Event'
                }
            }
          }
        },
        created_date: {
          required: false,
          read_only: true,
          serialized_name: 'properties.createdDate',
          type: {
            name: 'DateTime'
          }
        },
        provisioning_state: {
          required: false,
          serialized_name: 'properties.provisioningState',
          type: {
            name: 'String'
          }
        },
        unique_identifier: {
          required: false,
          serialized_name: 'properties.uniqueIdentifier',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end