Class: Azure::ARM::DevTestLabs::Models::ResourceCostProperties

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/resource_cost_properties.rb

Overview

The properties of a resource cost item.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#categoryString

to its size, for storage account it will be set to standard or premium

Returns:

  • (String)

    The category of the resource. For VM this will be set



29
30
31
# File 'lib/generated/azure_mgmt_devtestlabs/models/resource_cost_properties.rb', line 29

def category
  @category
end

#existsBoolean

Returns Whether the resource still exists or not.

Returns:

  • (Boolean)

    Whether the resource still exists or not



32
33
34
# File 'lib/generated/azure_mgmt_devtestlabs/models/resource_cost_properties.rb', line 32

def exists
  @exists
end

#ownerString

Returns The email address of the owner of the resource.

Returns:

  • (String)

    The email address of the owner of the resource



25
26
27
# File 'lib/generated/azure_mgmt_devtestlabs/models/resource_cost_properties.rb', line 25

def owner
  @owner
end

#resource_costFloat

Returns The cost component of the resource cost item.

Returns:

  • (Float)

    The cost component of the resource cost item.



22
23
24
# File 'lib/generated/azure_mgmt_devtestlabs/models/resource_cost_properties.rb', line 22

def resource_cost
  @resource_cost
end

#resource_group_nameString

Returns The name of the resource group.

Returns:

  • (String)

    The name of the resource group.



19
20
21
# File 'lib/generated/azure_mgmt_devtestlabs/models/resource_cost_properties.rb', line 19

def resource_group_name
  @resource_group_name
end

#resource_typeString

storageaccount)

Returns:

  • (String)

    The logical resource type (ex. virtualmachine,



36
37
38
# File 'lib/generated/azure_mgmt_devtestlabs/models/resource_cost_properties.rb', line 36

def resource_type
  @resource_type
end

#resourcenameString

Returns The name of the resource.

Returns:

  • (String)

    The name of the resource.



16
17
18
# File 'lib/generated/azure_mgmt_devtestlabs/models/resource_cost_properties.rb', line 16

def resourcename
  @resourcename
end

Class Method Details

.mapperObject

Mapper for ResourceCostProperties class as Ruby Hash. This will be used for serialization/deserialization.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/generated/azure_mgmt_devtestlabs/models/resource_cost_properties.rb', line 43

def self.mapper()
  {
    required: false,
    serialized_name: 'ResourceCostProperties',
    type: {
      name: 'Composite',
      class_name: 'ResourceCostProperties',
      model_properties: {
        resourcename: {
          required: false,
          serialized_name: 'resourcename',
          type: {
            name: 'String'
          }
        },
        resource_group_name: {
          required: false,
          serialized_name: 'resourceGroupName',
          type: {
            name: 'String'
          }
        },
        resource_cost: {
          required: false,
          serialized_name: 'resourceCost',
          type: {
            name: 'Double'
          }
        },
        owner: {
          required: false,
          serialized_name: 'owner',
          type: {
            name: 'String'
          }
        },
        category: {
          required: false,
          serialized_name: 'category',
          type: {
            name: 'String'
          }
        },
        exists: {
          required: false,
          serialized_name: 'exists',
          type: {
            name: 'Boolean'
          }
        },
        resource_type: {
          required: false,
          serialized_name: 'resourceType',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end