Class: Azure::ARM::DevTestLabs::Models::RetargetScheduleProperties

Inherits:
Object
  • Object
show all
Includes:
MsRest::JSONable, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/retarget_schedule_properties.rb

Overview

Properties for retargeting a virtual machine schedule.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#current_resource_idString

schedule operates

Returns:

  • (String)

    The resource Id of the virtual machine on which the



18
19
20
# File 'lib/generated/azure_mgmt_devtestlabs/models/retarget_schedule_properties.rb', line 18

def current_resource_id
  @current_resource_id
end

#target_resource_idString

schedule should be retargeted to

Returns:

  • (String)

    The resource Id of the virtual machine that the



22
23
24
# File 'lib/generated/azure_mgmt_devtestlabs/models/retarget_schedule_properties.rb', line 22

def target_resource_id
  @target_resource_id
end

Class Method Details

.mapperObject

Mapper for RetargetScheduleProperties class as Ruby Hash. This will be used for serialization/deserialization.



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/generated/azure_mgmt_devtestlabs/models/retarget_schedule_properties.rb', line 29

def self.mapper()
  {
    required: false,
    serialized_name: 'RetargetScheduleProperties',
    type: {
      name: 'Composite',
      class_name: 'RetargetScheduleProperties',
      model_properties: {
        current_resource_id: {
          required: false,
          serialized_name: 'currentResourceId',
          type: {
            name: 'String'
          }
        },
        target_resource_id: {
          required: false,
          serialized_name: 'targetResourceId',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end