Class: Azure::ARM::DevTestLabs::Models::ShutdownNotificationContent

Inherits:
Object
  • Object
show all
Includes:
MsRest::JSONable, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb

Overview

The contents of a shutdown notification. Webhooks can use this type to deserialize the request body when they get notified of an imminent shutdown.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#delay_url120String

Returns The URL to delay shutdown by 2 hours.

Returns:

  • (String)

    The URL to delay shutdown by 2 hours.



25
26
27
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 25

def delay_url120
  @delay_url120
end

#delay_url60String

Returns The URL to delay shutdown by 60 minutes.

Returns:

  • (String)

    The URL to delay shutdown by 60 minutes.



22
23
24
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 22

def delay_url60
  @delay_url60
end

#event_typeString

Returns The event for which a notification will be sent.

Returns:

  • (String)

    The event for which a notification will be sent.



37
38
39
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 37

def event_type
  @event_type
end

#guidString

Returns The GUID for the virtual machine to be shut down.

Returns:

  • (String)

    The GUID for the virtual machine to be shut down.



31
32
33
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 31

def guid
  @guid
end

#lab_nameString

Returns The lab for the schedule.

Returns:

  • (String)

    The lab for the schedule.



49
50
51
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 49

def lab_name
  @lab_name
end

#ownerString

Returns The owner of the virtual machine.

Returns:

  • (String)

    The owner of the virtual machine.



34
35
36
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 34

def owner
  @owner
end

#resource_group_nameString

Returns The resource group name for the schedule.

Returns:

  • (String)

    The resource group name for the schedule.



46
47
48
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 46

def resource_group_name
  @resource_group_name
end

#skip_urlString

Returns The URL to skip auto-shutdown.

Returns:

  • (String)

    The URL to skip auto-shutdown.



19
20
21
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 19

def skip_url
  @skip_url
end

#subscription_idString

Returns The subscription ID for the schedule.

Returns:

  • (String)

    The subscription ID for the schedule.



43
44
45
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 43

def subscription_id
  @subscription_id
end

#textString

Returns The text for the notification.

Returns:

  • (String)

    The text for the notification.



40
41
42
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 40

def text
  @text
end

#vm_nameString

Returns The virtual machine to be shut down.

Returns:

  • (String)

    The virtual machine to be shut down.



28
29
30
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 28

def vm_name
  @vm_name
end

Class Method Details

.mapperObject

Mapper for ShutdownNotificationContent class as Ruby Hash. This will be used for serialization/deserialization.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/generated/azure_mgmt_devtestlabs/models/shutdown_notification_content.rb', line 56

def self.mapper()
  {
    required: false,
    serialized_name: 'ShutdownNotificationContent',
    type: {
      name: 'Composite',
      class_name: 'ShutdownNotificationContent',
      model_properties: {
        skip_url: {
          required: false,
          serialized_name: 'skipUrl',
          type: {
            name: 'String'
          }
        },
        delay_url60: {
          required: false,
          serialized_name: 'delayUrl60',
          type: {
            name: 'String'
          }
        },
        delay_url120: {
          required: false,
          serialized_name: 'delayUrl120',
          type: {
            name: 'String'
          }
        },
        vm_name: {
          required: false,
          serialized_name: 'vmName',
          type: {
            name: 'String'
          }
        },
        guid: {
          required: false,
          serialized_name: 'guid',
          type: {
            name: 'String'
          }
        },
        owner: {
          required: false,
          serialized_name: 'owner',
          type: {
            name: 'String'
          }
        },
        event_type: {
          required: false,
          serialized_name: 'eventType',
          type: {
            name: 'String'
          }
        },
        text: {
          required: false,
          serialized_name: 'text',
          type: {
            name: 'String'
          }
        },
        subscription_id: {
          required: false,
          serialized_name: 'subscriptionId',
          type: {
            name: 'String'
          }
        },
        resource_group_name: {
          required: false,
          serialized_name: 'resourceGroupName',
          type: {
            name: 'String'
          }
        },
        lab_name: {
          required: false,
          serialized_name: 'labName',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end