Class: Azure::ARM::DevTestLabs::Models::SubnetFragment

Inherits:
Object
  • Object
show all
Includes:
MsRest::JSONable, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/subnet_fragment.rb

Overview

Subnet information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#allow_public_ipUsagePermissionType

allowing public IP addresses (i.e. Allow, Deny)). Possible values include: ‘Default’, ‘Deny’, ‘Allow’

Returns:



25
26
27
# File 'lib/generated/azure_mgmt_devtestlabs/models/subnet_fragment.rb', line 25

def allow_public_ip
  @allow_public_ip
end

#lab_subnet_nameString

Returns The name of the subnet as seen in the lab.

Returns:

  • (String)

    The name of the subnet as seen in the lab.



20
21
22
# File 'lib/generated/azure_mgmt_devtestlabs/models/subnet_fragment.rb', line 20

def lab_subnet_name
  @lab_subnet_name
end

#resource_idString

Returns The resource ID of the subnet.

Returns:

  • (String)

    The resource ID of the subnet.



17
18
19
# File 'lib/generated/azure_mgmt_devtestlabs/models/subnet_fragment.rb', line 17

def resource_id
  @resource_id
end

Class Method Details

.mapperObject

Mapper for SubnetFragment class as Ruby Hash. This will be used for serialization/deserialization.



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/generated/azure_mgmt_devtestlabs/models/subnet_fragment.rb', line 32

def self.mapper()
  {
    required: false,
    serialized_name: 'SubnetFragment',
    type: {
      name: 'Composite',
      class_name: 'SubnetFragment',
      model_properties: {
        resource_id: {
          required: false,
          serialized_name: 'resourceId',
          type: {
            name: 'String'
          }
        },
        lab_subnet_name: {
          required: false,
          serialized_name: 'labSubnetName',
          type: {
            name: 'String'
          }
        },
        allow_public_ip: {
          required: false,
          serialized_name: 'allowPublicIp',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end