Class: Azure::ARM::DevTestLabs::Models::UserIdentity

Inherits:
Object
  • Object
show all
Includes:
MsRest::JSONable, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/user_identity.rb

Overview

Identity attributes of a lab user.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#app_idString

request.

Returns:

  • (String)

    Set to the app Id of the client JWT making the



35
36
37
# File 'lib/generated/azure_mgmt_devtestlabs/models/user_identity.rb', line 35

def app_id
  @app_id
end

#object_idString

request. Not all users have object Id. For CSP (reseller) scenarios for example, object Id is not available.

Returns:

  • (String)

    Set to the object Id of the client JWT making the



31
32
33
# File 'lib/generated/azure_mgmt_devtestlabs/models/user_identity.rb', line 31

def object_id
  @object_id
end

#principal_idString

request. Service principal will not have the principal Id.

Returns:

  • (String)

    Set to the principal Id of the client JWT making the



22
23
24
# File 'lib/generated/azure_mgmt_devtestlabs/models/user_identity.rb', line 22

def principal_id
  @principal_id
end

#principal_nameString

making the request.

Returns:

  • (String)

    Set to the principal name / UPN of the client JWT



18
19
20
# File 'lib/generated/azure_mgmt_devtestlabs/models/user_identity.rb', line 18

def principal_name
  @principal_name
end

#tenant_idString

request.

Returns:

  • (String)

    Set to the tenant ID of the client JWT making the



26
27
28
# File 'lib/generated/azure_mgmt_devtestlabs/models/user_identity.rb', line 26

def tenant_id
  @tenant_id
end

Class Method Details

.mapperObject

Mapper for UserIdentity class as Ruby Hash. This will be used for serialization/deserialization.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/generated/azure_mgmt_devtestlabs/models/user_identity.rb', line 42

def self.mapper()
  {
    required: false,
    serialized_name: 'UserIdentity',
    type: {
      name: 'Composite',
      class_name: 'UserIdentity',
      model_properties: {
        principal_name: {
          required: false,
          serialized_name: 'principalName',
          type: {
            name: 'String'
          }
        },
        principal_id: {
          required: false,
          serialized_name: 'principalId',
          type: {
            name: 'String'
          }
        },
        tenant_id: {
          required: false,
          serialized_name: 'tenantId',
          type: {
            name: 'String'
          }
        },
        object_id: {
          required: false,
          serialized_name: 'objectId',
          type: {
            name: 'String'
          }
        },
        app_id: {
          required: false,
          serialized_name: 'appId',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end