Class: Azure::ARM::DevTestLabs::PolicyOperations

Inherits:
Object
  • Object
show all
Includes:
Models, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/policy_operations.rb

Overview

The DevTest Labs Client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ PolicyOperations

Creates and initializes a new instance of the PolicyOperations class.

Parameters:

  • service class for accessing basic functionality.



18
19
20
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 18

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientDevTestLabsClient (readonly)

Returns reference to the DevTestLabsClient.

Returns:

  • reference to the DevTestLabsClient



23
24
25
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 23

def client
  @client
end

Instance Method Details

#create_or_update_resource(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil) ⇒ Policy

Create or replace an existing policy.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



281
282
283
284
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 281

def create_or_update_resource(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil)
  response = create_or_update_resource_async(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers).value!
  response.body unless response.nil?
end

#create_or_update_resource_async(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil) ⇒ Concurrent::Promise

Create or replace an existing policy.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 316

def create_or_update_resource_async(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'policy_set_name is nil' if policy_set_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'policy is nil' if policy.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = Policy.mapper()
  request_content = @client.serialize(request_mapper,  policy, 'policy')
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/policysets/{policySetName}/policies/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'policySetName' => policy_set_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :put, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 201
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Policy.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end
    # Deserialize Response
    if status_code == 201
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Policy.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#create_or_update_resource_with_http_info(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Create or replace an existing policy.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



299
300
301
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 299

def create_or_update_resource_with_http_info(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil)
  create_or_update_resource_async(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers).value!
end

#delete_resource(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil) ⇒ Object

Delete policy.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • (defaults to: nil)

    A hash of custom headers that



404
405
406
407
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 404

def delete_resource(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil)
  response = delete_resource_async(resource_group_name, lab_name, policy_set_name, name, custom_headers).value!
  nil
end

#delete_resource_async(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Delete policy.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 437

def delete_resource_async(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'policy_set_name is nil' if policy_set_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/policysets/{policySetName}/policies/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'policySetName' => policy_set_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :delete, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 204
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#delete_resource_with_http_info(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Delete policy.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



421
422
423
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 421

def delete_resource_with_http_info(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil)
  delete_resource_async(resource_group_name, lab_name, policy_set_name, name, custom_headers).value!
end

#get_resource(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil) ⇒ Policy

Get policy.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



178
179
180
181
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 178

def get_resource(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil)
  response = get_resource_async(resource_group_name, lab_name, policy_set_name, name, custom_headers).value!
  response.body unless response.nil?
end

#get_resource_async(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Get policy.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 211

def get_resource_async(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'policy_set_name is nil' if policy_set_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/policysets/{policySetName}/policies/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'policySetName' => policy_set_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Policy.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_resource_with_http_info(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Get policy.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



195
196
197
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 195

def get_resource_with_http_info(resource_group_name, lab_name, policy_set_name, name, custom_headers = nil)
  get_resource_async(resource_group_name, lab_name, policy_set_name, name, custom_headers).value!
end

#list(resource_group_name, lab_name, policy_set_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Array<Policy>

List policies in a given policy set.

operation. OData notation. will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



69
70
71
72
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 69

def list(resource_group_name, lab_name, policy_set_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  first_page = list_as_lazy(resource_group_name, lab_name, policy_set_name, filter, top, order_by, custom_headers)
  first_page.get_all_items
end

#list_as_lazy(resource_group_name, lab_name, policy_set_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ ResponseWithContinuationPolicy

List policies in a given policy set.

operation. OData notation. will be added to the HTTP request.

of the response.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • which provide lazy access to pages



42
43
44
45
46
47
48
49
50
51
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 42

def list_as_lazy(resource_group_name, lab_name, policy_set_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  response = list_async(resource_group_name, lab_name, policy_set_name, filter, top, order_by, custom_headers).value!
  unless response.nil?
    page = response.body
    page.next_method = Proc.new do |next_link|
      list_next_async(next_link, custom_headers)
    end
    page
  end
end

#list_async(resource_group_name, lab_name, policy_set_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Concurrent::Promise

List policies in a given policy set.

operation. OData notation. to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 110

def list_async(resource_group_name, lab_name, policy_set_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'policy_set_name is nil' if policy_set_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/policysets/{policySetName}/policies'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'policySetName' => policy_set_name},
      query_params: {'$filter' => filter,'$top' => top,'$orderBy' => order_by,'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = ResponseWithContinuationPolicy.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationPolicy

List policies in a given policy set.

call to List operation. will be added to the HTTP request.

Parameters:

  • The NextLink from the previous successful

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



609
610
611
612
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 609

def list_next(next_page_link, custom_headers = nil)
  response = list_next_async(next_page_link, custom_headers).value!
  response.body unless response.nil?
end

#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise

List policies in a given policy set.

call to List operation. to the HTTP request.

Parameters:

  • The NextLink from the previous successful

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 638

def list_next_async(next_page_link, custom_headers = nil)
  fail ArgumentError, 'next_page_link is nil' if next_page_link.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '{nextLink}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      skip_encoding_path_params: {'nextLink' => next_page_link},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = ResponseWithContinuationPolicy.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List policies in a given policy set.

call to List operation. will be added to the HTTP request.

Parameters:

  • The NextLink from the previous successful

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



624
625
626
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 624

def list_next_with_http_info(next_page_link, custom_headers = nil)
  list_next_async(next_page_link, custom_headers).value!
end

#list_with_http_info(resource_group_name, lab_name, policy_set_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List policies in a given policy set.

operation. OData notation. will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



90
91
92
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 90

def list_with_http_info(resource_group_name, lab_name, policy_set_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  list_async(resource_group_name, lab_name, policy_set_name, filter, top, order_by, custom_headers).value!
end

#patch_resource(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil) ⇒ Policy

Modify properties of policies.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



497
498
499
500
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 497

def patch_resource(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil)
  response = patch_resource_async(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers).value!
  response.body unless response.nil?
end

#patch_resource_async(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil) ⇒ Concurrent::Promise

Modify properties of policies.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 532

def patch_resource_async(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'policy_set_name is nil' if policy_set_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'policy is nil' if policy.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = Policy.mapper()
  request_content = @client.serialize(request_mapper,  policy, 'policy')
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/policysets/{policySetName}/policies/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'policySetName' => policy_set_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :patch, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Policy.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#patch_resource_with_http_info(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Modify properties of policies.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the policy set.

  • The name of the policy.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



515
516
517
# File 'lib/generated/azure_mgmt_devtestlabs/policy_operations.rb', line 515

def patch_resource_with_http_info(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers = nil)
  patch_resource_async(resource_group_name, lab_name, policy_set_name, name, policy, custom_headers).value!
end