Class: Azure::ARM::DevTestLabs::VirtualMachineSchedules

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb

Overview

The DevTest Labs Client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ VirtualMachineSchedules

Creates and initializes a new instance of the VirtualMachineSchedules class.

Parameters:

  • client

    service class for accessing basic functionality.



17
18
19
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 17

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientDevTestLabsClient (readonly)

Returns reference to the DevTestLabsClient.

Returns:



22
23
24
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 22

def client
  @client
end

Instance Method Details

#begin_execute(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil) ⇒ Object

Execute a schedule. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



620
621
622
623
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 620

def begin_execute(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil)
  response = begin_execute_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers).value!
  nil
end

#begin_execute_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Execute a schedule. This operation can take a while to complete.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 653

def begin_execute_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'virtual_machine_name is nil' if virtual_machine_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{virtualMachineName}/schedules/{name}/execute'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'virtualMachineName' => virtual_machine_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:post, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 202
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#begin_execute_with_http_info(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Execute a schedule. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



637
638
639
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 637

def begin_execute_with_http_info(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil)
  begin_execute_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers).value!
end

#create_or_update(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil) ⇒ Schedule

Create or replace an existing schedule.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • schedule (Schedule)

    A schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Schedule)

    operation results.



258
259
260
261
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 258

def create_or_update(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil)
  response = create_or_update_async(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers).value!
  response.body unless response.nil?
end

#create_or_update_async(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil) ⇒ Concurrent::Promise

Create or replace an existing schedule.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • schedule (Schedule)

    A schedule.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 293

def create_or_update_async(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'virtual_machine_name is nil' if virtual_machine_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'schedule is nil' if schedule.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = Azure::ARM::DevTestLabs::Models::Schedule.mapper()
  request_content = @client.serialize(request_mapper,  schedule)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{virtualMachineName}/schedules/{name}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'virtualMachineName' => virtual_machine_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:put, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 201
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::Schedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end
    # Deserialize Response
    if status_code == 201
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::Schedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#create_or_update_with_http_info(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Create or replace an existing schedule.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • schedule (Schedule)

    A schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



276
277
278
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 276

def create_or_update_with_http_info(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil)
  create_or_update_async(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers).value!
end

#delete(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil) ⇒ Object

Delete schedule.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



378
379
380
381
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 378

def delete(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil)
  response = delete_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers).value!
  nil
end

#delete_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Delete schedule.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 411

def delete_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'virtual_machine_name is nil' if virtual_machine_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{virtualMachineName}/schedules/{name}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'virtualMachineName' => virtual_machine_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:delete, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 204
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#delete_with_http_info(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Delete schedule.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



395
396
397
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 395

def delete_with_http_info(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil)
  delete_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers).value!
end

#execute(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil) ⇒ Object

Execute a schedule. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



577
578
579
580
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 577

def execute(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil)
  response = execute_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers).value!
  nil
end

#execute_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil) ⇒ Concurrent::Promise

will be added to the HTTP request.

response.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Concurrent::Promise)

    promise which provides async access to http



593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 593

def execute_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers = nil)
  # Send request
  promise = begin_execute_async(resource_group_name, lab_name, virtual_machine_name, name, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#get(resource_group_name, lab_name, virtual_machine_name, name, expand = nil, custom_headers = nil) ⇒ Schedule

Get schedule.

‘properties($select=status)’ will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Schedule)

    operation results.



154
155
156
157
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 154

def get(resource_group_name, lab_name, virtual_machine_name, name, expand = nil, custom_headers = nil)
  response = get_async(resource_group_name, lab_name, virtual_machine_name, name, expand, custom_headers).value!
  response.body unless response.nil?
end

#get_async(resource_group_name, lab_name, virtual_machine_name, name, expand = nil, custom_headers = nil) ⇒ Concurrent::Promise

Get schedule.

‘properties($select=status)’ to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 191

def get_async(resource_group_name, lab_name, virtual_machine_name, name, expand = nil, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'virtual_machine_name is nil' if virtual_machine_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{virtualMachineName}/schedules/{name}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'virtualMachineName' => virtual_machine_name,'name' => name},
      query_params: {'$expand' => expand,'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::Schedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_with_http_info(resource_group_name, lab_name, virtual_machine_name, name, expand = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Get schedule.

‘properties($select=status)’ will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



173
174
175
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 173

def get_with_http_info(resource_group_name, lab_name, virtual_machine_name, name, expand = nil, custom_headers = nil)
  get_async(resource_group_name, lab_name, virtual_machine_name, name, expand, custom_headers).value!
end

#list(resource_group_name, lab_name, virtual_machine_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ Array<Schedule>

List schedules in a given virtual machine.

‘properties($select=status)’ operation. notation. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • filter (String) (defaults to: nil)

    The filter to apply to the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • orderby (String) (defaults to: nil)

    The ordering expression for the results, using OData

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Array<Schedule>)

    operation results.



42
43
44
45
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 42

def list(resource_group_name, lab_name, virtual_machine_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil)
  first_page = list_as_lazy(resource_group_name, lab_name, virtual_machine_name, expand, filter, top, orderby, custom_headers)
  first_page.get_all_items
end

#list_as_lazy(resource_group_name, lab_name, virtual_machine_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ ResponseWithContinuationSchedule

List schedules in a given virtual machine.

‘properties($select=status)’ operation. notation. will be added to the HTTP request.

of the response.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • filter (String) (defaults to: nil)

    The filter to apply to the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • orderby (String) (defaults to: nil)

    The ordering expression for the results, using OData

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ResponseWithContinuationSchedule)

    which provide lazy access to pages



803
804
805
806
807
808
809
810
811
812
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 803

def list_as_lazy(resource_group_name, lab_name, virtual_machine_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil)
  response = list_async(resource_group_name, lab_name, virtual_machine_name, expand, filter, top, orderby, custom_headers).value!
  unless response.nil?
    page = response.body
    page.next_method = Proc.new do |next_page_link|
      list_next_async(next_page_link, custom_headers)
    end
    page
  end
end

#list_async(resource_group_name, lab_name, virtual_machine_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ Concurrent::Promise

List schedules in a given virtual machine.

‘properties($select=status)’ operation. notation. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • filter (String) (defaults to: nil)

    The filter to apply to the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • orderby (String) (defaults to: nil)

    The ordering expression for the results, using OData

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 87

def list_async(resource_group_name, lab_name, virtual_machine_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'virtual_machine_name is nil' if virtual_machine_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{virtualMachineName}/schedules'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'virtualMachineName' => virtual_machine_name},
      query_params: {'$expand' => expand,'$filter' => filter,'$top' => top,'$orderby' => orderby,'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::ResponseWithContinuationSchedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationSchedule

List schedules in a given virtual machine.

to List operation. will be added to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (ResponseWithContinuationSchedule)

    operation results.



707
708
709
710
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 707

def list_next(next_page_link, custom_headers = nil)
  response = list_next_async(next_page_link, custom_headers).value!
  response.body unless response.nil?
end

#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise

List schedules in a given virtual machine.

to List operation. to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 736

def list_next_async(next_page_link, custom_headers = nil)
  fail ArgumentError, 'next_page_link is nil' if next_page_link.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '{nextLink}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      skip_encoding_path_params: {'nextLink' => next_page_link},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::ResponseWithContinuationSchedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List schedules in a given virtual machine.

to List operation. will be added to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



722
723
724
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 722

def list_next_with_http_info(next_page_link, custom_headers = nil)
  list_next_async(next_page_link, custom_headers).value!
end

#list_with_http_info(resource_group_name, lab_name, virtual_machine_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List schedules in a given virtual machine.

‘properties($select=status)’ operation. notation. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • expand (String) (defaults to: nil)

    Specify the $expand query. Example:

  • filter (String) (defaults to: nil)

    The filter to apply to the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • orderby (String) (defaults to: nil)

    The ordering expression for the results, using OData

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



65
66
67
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 65

def list_with_http_info(resource_group_name, lab_name, virtual_machine_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil)
  list_async(resource_group_name, lab_name, virtual_machine_name, expand, filter, top, orderby, custom_headers).value!
end

#update(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil) ⇒ Schedule

Modify properties of schedules.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • schedule (ScheduleFragment)

    A schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Schedule)

    operation results.



468
469
470
471
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 468

def update(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil)
  response = update_async(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers).value!
  response.body unless response.nil?
end

#update_async(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil) ⇒ Concurrent::Promise

Modify properties of schedules.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • schedule (ScheduleFragment)

    A schedule.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 503

def update_async(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'virtual_machine_name is nil' if virtual_machine_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'schedule is nil' if schedule.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = Azure::ARM::DevTestLabs::Models::ScheduleFragment.mapper()
  request_content = @client.serialize(request_mapper,  schedule)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{virtualMachineName}/schedules/{name}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'virtualMachineName' => virtual_machine_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:patch, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::ARM::DevTestLabs::Models::Schedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#update_with_http_info(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Modify properties of schedules.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • virtual_machine_name (String)

    The name of the virtual machine.

  • name (String)

    The name of the schedule.

  • schedule (ScheduleFragment)

    A schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



486
487
488
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine_schedules.rb', line 486

def update_with_http_info(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers = nil)
  update_async(resource_group_name, lab_name, virtual_machine_name, name, schedule, custom_headers).value!
end