Class: Azure::ARM::DevTestLabs::CustomImages
- Inherits:
-
Object
- Object
- Azure::ARM::DevTestLabs::CustomImages
- Includes:
- MsRestAzure
- Defined in:
- lib/generated/azure_mgmt_devtestlabs/custom_images.rb
Overview
The DevTest Labs Client.
Instance Attribute Summary collapse
-
#client ⇒ DevTestLabsClient
readonly
Reference to the DevTestLabsClient.
Instance Method Summary collapse
-
#begin_create_or_update(resource_group_name, lab_name, name, custom_image, custom_headers = nil) ⇒ CustomImage
Create or replace an existing custom image.
-
#begin_create_or_update_async(resource_group_name, lab_name, name, custom_image, custom_headers = nil) ⇒ Concurrent::Promise
Create or replace an existing custom image.
-
#begin_create_or_update_with_http_info(resource_group_name, lab_name, name, custom_image, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Create or replace an existing custom image.
-
#begin_delete(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object
Delete custom image.
-
#begin_delete_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise
Delete custom image.
-
#begin_delete_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Delete custom image.
-
#create_or_update(resource_group_name, lab_name, name, custom_image, custom_headers = nil) ⇒ CustomImage
Create or replace an existing custom image.
-
#create_or_update_async(resource_group_name, lab_name, name, custom_image, custom_headers = nil) ⇒ Concurrent::Promise
will be added to the HTTP request.
-
#delete(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object
Delete custom image.
-
#delete_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise
will be added to the HTTP request.
-
#get(resource_group_name, lab_name, name, expand = nil, custom_headers = nil) ⇒ CustomImage
Get custom image.
-
#get_async(resource_group_name, lab_name, name, expand = nil, custom_headers = nil) ⇒ Concurrent::Promise
Get custom image.
-
#get_with_http_info(resource_group_name, lab_name, name, expand = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Get custom image.
-
#initialize(client) ⇒ CustomImages
constructor
Creates and initializes a new instance of the CustomImages class.
-
#list(resource_group_name, lab_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ Array<CustomImage>
List custom images in a given lab.
-
#list_as_lazy(resource_group_name, lab_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ ResponseWithContinuationCustomImage
List custom images in a given lab.
-
#list_async(resource_group_name, lab_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ Concurrent::Promise
List custom images in a given lab.
-
#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationCustomImage
List custom images in a given lab.
-
#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise
List custom images in a given lab.
-
#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List custom images in a given lab.
-
#list_with_http_info(resource_group_name, lab_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List custom images in a given lab.
Constructor Details
#initialize(client) ⇒ CustomImages
Creates and initializes a new instance of the CustomImages class.
17 18 19 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 17 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ DevTestLabsClient (readonly)
Returns reference to the DevTestLabsClient.
22 23 24 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 22 def client @client end |
Instance Method Details
#begin_create_or_update(resource_group_name, lab_name, name, custom_image, custom_headers = nil) ⇒ CustomImage
Create or replace an existing custom image. This operation can take a while to complete.
will be added to the HTTP request.
337 338 339 340 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 337 def begin_create_or_update(resource_group_name, lab_name, name, custom_image, custom_headers = nil) response = begin_create_or_update_async(resource_group_name, lab_name, name, custom_image, custom_headers).value! response.body unless response.nil? end |
#begin_create_or_update_async(resource_group_name, lab_name, name, custom_image, custom_headers = nil) ⇒ Concurrent::Promise
Create or replace an existing custom image. This operation can take a while to complete.
to the HTTP request.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 372 def begin_create_or_update_async(resource_group_name, lab_name, name, custom_image, custom_headers = nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'lab_name is nil' if lab_name.nil? fail ArgumentError, 'name is nil' if name.nil? fail ArgumentError, 'custom_image is nil' if custom_image.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? request_headers['Content-Type'] = 'application/json; charset=utf-8' # Serialize Request request_mapper = Azure::ARM::DevTestLabs::Models::CustomImage.mapper() request_content = @client.serialize(request_mapper, custom_image) request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/customimages/{name}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:put, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 || status_code == 201 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::ARM::DevTestLabs::Models::CustomImage.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end # Deserialize Response if status_code == 201 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::ARM::DevTestLabs::Models::CustomImage.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#begin_create_or_update_with_http_info(resource_group_name, lab_name, name, custom_image, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Create or replace an existing custom image. This operation can take a while to complete.
will be added to the HTTP request.
355 356 357 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 355 def begin_create_or_update_with_http_info(resource_group_name, lab_name, name, custom_image, custom_headers = nil) begin_create_or_update_async(resource_group_name, lab_name, name, custom_image, custom_headers).value! end |
#begin_delete(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object
Delete custom image. This operation can take a while to complete.
will be added to the HTTP request.
455 456 457 458 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 455 def begin_delete(resource_group_name, lab_name, name, custom_headers = nil) response = begin_delete_async(resource_group_name, lab_name, name, custom_headers).value! nil end |
#begin_delete_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise
Delete custom image. This operation can take a while to complete.
to the HTTP request.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 486 def begin_delete_async(resource_group_name, lab_name, name, custom_headers = nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'lab_name is nil' if lab_name.nil? fail ArgumentError, 'name is nil' if name.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/customimages/{name}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:delete, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 202 || status_code == 204 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result end promise.execute end |
#begin_delete_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Delete custom image. This operation can take a while to complete.
will be added to the HTTP request.
471 472 473 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 471 def begin_delete_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) begin_delete_async(resource_group_name, lab_name, name, custom_headers).value! end |
#create_or_update(resource_group_name, lab_name, name, custom_image, custom_headers = nil) ⇒ CustomImage
Create or replace an existing custom image. This operation can take a while to complete.
will be added to the HTTP request.
250 251 252 253 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 250 def create_or_update(resource_group_name, lab_name, name, custom_image, custom_headers = nil) response = create_or_update_async(resource_group_name, lab_name, name, custom_image, custom_headers).value! response.body unless response.nil? end |
#create_or_update_async(resource_group_name, lab_name, name, custom_image, custom_headers = nil) ⇒ Concurrent::Promise
will be added to the HTTP request.
response.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 266 def create_or_update_async(resource_group_name, lab_name, name, custom_image, custom_headers = nil) # Send request promise = begin_create_or_update_async(resource_group_name, lab_name, name, custom_image, custom_headers) promise = promise.then do |response| # Defining deserialization method. deserialize_method = lambda do |parsed_response| result_mapper = Azure::ARM::DevTestLabs::Models::CustomImage.mapper() parsed_response = @client.deserialize(result_mapper, parsed_response) end # Waiting for response. @client.get_long_running_operation_result(response, deserialize_method) end promise end |
#delete(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object
Delete custom image. This operation can take a while to complete.
will be added to the HTTP request.
293 294 295 296 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 293 def delete(resource_group_name, lab_name, name, custom_headers = nil) response = delete_async(resource_group_name, lab_name, name, custom_headers).value! nil end |
#delete_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise
will be added to the HTTP request.
response.
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 308 def delete_async(resource_group_name, lab_name, name, custom_headers = nil) # Send request promise = begin_delete_async(resource_group_name, lab_name, name, custom_headers) promise = promise.then do |response| # Defining deserialization method. deserialize_method = lambda do |parsed_response| end # Waiting for response. @client.get_long_running_operation_result(response, deserialize_method) end promise end |
#get(resource_group_name, lab_name, name, expand = nil, custom_headers = nil) ⇒ CustomImage
Get custom image.
‘properties($select=vm)’ will be added to the HTTP request.
149 150 151 152 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 149 def get(resource_group_name, lab_name, name, = nil, custom_headers = nil) response = get_async(resource_group_name, lab_name, name, , custom_headers).value! response.body unless response.nil? end |
#get_async(resource_group_name, lab_name, name, expand = nil, custom_headers = nil) ⇒ Concurrent::Promise
Get custom image.
‘properties($select=vm)’ to the HTTP request.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 184 def get_async(resource_group_name, lab_name, name, = nil, custom_headers = nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'lab_name is nil' if lab_name.nil? fail ArgumentError, 'name is nil' if name.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/customimages/{name}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name}, query_params: {'$expand' => ,'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::ARM::DevTestLabs::Models::CustomImage.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_with_http_info(resource_group_name, lab_name, name, expand = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Get custom image.
‘properties($select=vm)’ will be added to the HTTP request.
167 168 169 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 167 def get_with_http_info(resource_group_name, lab_name, name, = nil, custom_headers = nil) get_async(resource_group_name, lab_name, name, , custom_headers).value! end |
#list(resource_group_name, lab_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ Array<CustomImage>
List custom images in a given lab.
‘properties($select=vm)’ operation. notation. will be added to the HTTP request.
41 42 43 44 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 41 def list(resource_group_name, lab_name, = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) first_page = list_as_lazy(resource_group_name, lab_name, , filter, top, orderby, custom_headers) first_page.get_all_items end |
#list_as_lazy(resource_group_name, lab_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ ResponseWithContinuationCustomImage
List custom images in a given lab.
‘properties($select=vm)’ operation. notation. will be added to the HTTP request.
pages of the response.
634 635 636 637 638 639 640 641 642 643 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 634 def list_as_lazy(resource_group_name, lab_name, = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) response = list_async(resource_group_name, lab_name, , filter, top, orderby, custom_headers).value! unless response.nil? page = response.body page.next_method = Proc.new do |next_page_link| list_next_async(next_page_link, custom_headers) end page end end |
#list_async(resource_group_name, lab_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ Concurrent::Promise
List custom images in a given lab.
‘properties($select=vm)’ operation. notation. to the HTTP request.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 84 def list_async(resource_group_name, lab_name, = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'lab_name is nil' if lab_name.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/customimages' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name}, query_params: {'$expand' => ,'$filter' => filter,'$top' => top,'$orderby' => orderby,'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::ARM::DevTestLabs::Models::ResponseWithContinuationCustomImage.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationCustomImage
List custom images in a given lab.
to List operation. will be added to the HTTP request.
539 540 541 542 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 539 def list_next(next_page_link, custom_headers = nil) response = list_next_async(next_page_link, custom_headers).value! response.body unless response.nil? end |
#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise
List custom images in a given lab.
to List operation. to the HTTP request.
568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 568 def list_next_async(next_page_link, custom_headers = nil) fail ArgumentError, 'next_page_link is nil' if next_page_link.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{nextLink}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'nextLink' => next_page_link}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::ARM::DevTestLabs::Models::ResponseWithContinuationCustomImage.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List custom images in a given lab.
to List operation. will be added to the HTTP request.
554 555 556 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 554 def list_next_with_http_info(next_page_link, custom_headers = nil) list_next_async(next_page_link, custom_headers).value! end |
#list_with_http_info(resource_group_name, lab_name, expand = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List custom images in a given lab.
‘properties($select=vm)’ operation. notation. will be added to the HTTP request.
63 64 65 |
# File 'lib/generated/azure_mgmt_devtestlabs/custom_images.rb', line 63 def list_with_http_info(resource_group_name, lab_name, = nil, filter = nil, top = nil, orderby = nil, custom_headers = nil) list_async(resource_group_name, lab_name, , filter, top, orderby, custom_headers).value! end |