Class: Azure::ARM::DevTestLabs::DevTestLabsClient
- Inherits:
-
MsRestAzure::AzureServiceClient
- Object
- MsRestAzure::AzureServiceClient
- Azure::ARM::DevTestLabs::DevTestLabsClient
- Includes:
- MsRestAzure, MsRestAzure::Serialization
- Defined in:
- lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb
Overview
A service client - single point of access to the REST API.
Instance Attribute Summary collapse
-
#accept_language ⇒ String
Gets or sets the preferred language for the response.
-
#api_version ⇒ String
readonly
Client API version.
-
#artifact_operations ⇒ ArtifactOperations
readonly
Artifact_operations.
-
#artifact_source_operations ⇒ ArtifactSourceOperations
readonly
Artifact_source_operations.
-
#base_url ⇒ String
The base URI of the service.
-
#cost_operations ⇒ CostOperations
readonly
Cost_operations.
-
#credentials ⇒ Object
readonly
Credentials needed for the client to connect to Azure.
-
#custom_image_operations ⇒ CustomImageOperations
readonly
Custom_image_operations.
-
#formula_operations ⇒ FormulaOperations
readonly
Formula_operations.
-
#gallery_image_operations ⇒ GalleryImageOperations
readonly
Gallery_image_operations.
-
#generate_client_request_id ⇒ Boolean
is generated and included in each request.
-
#lab_operations ⇒ LabOperations
readonly
Lab_operations.
-
#long_running_operation_retry_timeout ⇒ Integer
Running Operations.
-
#policy_operations ⇒ PolicyOperations
readonly
Policy_operations.
-
#policy_set ⇒ PolicySet
readonly
Policy_set.
-
#schedule_operations ⇒ ScheduleOperations
readonly
Schedule_operations.
-
#subscription_id ⇒ String
The subscription ID.
-
#virtual_machine ⇒ VirtualMachine
readonly
Virtual_machine.
-
#virtual_network_operations ⇒ VirtualNetworkOperations
readonly
Virtual_network_operations.
Instance Method Summary collapse
-
#initialize(credentials = nil, base_url = nil, options = nil) ⇒ DevTestLabsClient
constructor
Creates initializes a new instance of the DevTestLabsClient class.
-
#make_request(method, path, options = {}) ⇒ Hash{String=>String}
Makes a request and returns the body of the response.
-
#make_request_async(method, path, options = {}) ⇒ Concurrent::Promise
Makes a request asynchronously.
-
#make_request_with_http_info(method, path, options = {}) ⇒ MsRestAzure::AzureOperationResponse
Makes a request and returns the operation response.
Constructor Details
#initialize(credentials = nil, base_url = nil, options = nil) ⇒ DevTestLabsClient
Creates initializes a new instance of the DevTestLabsClient class.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 79 def initialize(credentials = nil, base_url = nil, = nil) super(credentials, ) @base_url = base_url || 'https://management.azure.com' fail ArgumentError, 'invalid type of credentials input parameter' unless credentials.is_a?(MsRest::ServiceClientCredentials) unless credentials.nil? @credentials = credentials @lab_operations = LabOperations.new(self) @artifact_source_operations = ArtifactSourceOperations.new(self) @artifact_operations = ArtifactOperations.new(self) @cost_operations = CostOperations.new(self) @custom_image_operations = CustomImageOperations.new(self) @formula_operations = FormulaOperations.new(self) @gallery_image_operations = GalleryImageOperations.new(self) @policy_set = PolicySet.new(self) @policy_operations = PolicyOperations.new(self) @schedule_operations = ScheduleOperations.new(self) @virtual_machine = VirtualMachine.new(self) @virtual_network_operations = VirtualNetworkOperations.new(self) @api_version = '2016-05-15' @accept_language = 'en-US' @long_running_operation_retry_timeout = 30 @generate_client_request_id = true add_telemetry end |
Instance Attribute Details
#accept_language ⇒ String
Returns Gets or sets the preferred language for the response.
27 28 29 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 27 def accept_language @accept_language end |
#api_version ⇒ String (readonly)
Returns Client API version.
21 22 23 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 21 def api_version @api_version end |
#artifact_operations ⇒ ArtifactOperations (readonly)
Returns artifact_operations.
44 45 46 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 44 def artifact_operations @artifact_operations end |
#artifact_source_operations ⇒ ArtifactSourceOperations (readonly)
Returns artifact_source_operations.
41 42 43 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 41 def artifact_source_operations @artifact_source_operations end |
#base_url ⇒ String
Returns the base URI of the service.
15 16 17 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 15 def base_url @base_url end |
#cost_operations ⇒ CostOperations (readonly)
Returns cost_operations.
47 48 49 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 47 def cost_operations @cost_operations end |
#credentials ⇒ Object (readonly)
Returns Credentials needed for the client to connect to Azure.
18 19 20 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 18 def credentials @credentials end |
#custom_image_operations ⇒ CustomImageOperations (readonly)
Returns custom_image_operations.
50 51 52 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 50 def custom_image_operations @custom_image_operations end |
#formula_operations ⇒ FormulaOperations (readonly)
Returns formula_operations.
53 54 55 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 53 def formula_operations @formula_operations end |
#gallery_image_operations ⇒ GalleryImageOperations (readonly)
Returns gallery_image_operations.
56 57 58 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 56 def gallery_image_operations @gallery_image_operations end |
#generate_client_request_id ⇒ Boolean
is generated and included in each request. Default is true.
35 36 37 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 35 def generate_client_request_id @generate_client_request_id end |
#lab_operations ⇒ LabOperations (readonly)
Returns lab_operations.
38 39 40 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 38 def lab_operations @lab_operations end |
#long_running_operation_retry_timeout ⇒ Integer
Running Operations. Default value is 30.
31 32 33 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 31 def long_running_operation_retry_timeout @long_running_operation_retry_timeout end |
#policy_operations ⇒ PolicyOperations (readonly)
Returns policy_operations.
62 63 64 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 62 def policy_operations @policy_operations end |
#policy_set ⇒ PolicySet (readonly)
Returns policy_set.
59 60 61 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 59 def policy_set @policy_set end |
#schedule_operations ⇒ ScheduleOperations (readonly)
Returns schedule_operations.
65 66 67 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 65 def schedule_operations @schedule_operations end |
#subscription_id ⇒ String
Returns The subscription ID.
24 25 26 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 24 def subscription_id @subscription_id end |
#virtual_machine ⇒ VirtualMachine (readonly)
Returns virtual_machine.
68 69 70 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 68 def virtual_machine @virtual_machine end |
#virtual_network_operations ⇒ VirtualNetworkOperations (readonly)
Returns virtual_network_operations.
71 72 73 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 71 def virtual_network_operations @virtual_network_operations end |
Instance Method Details
#make_request(method, path, options = {}) ⇒ Hash{String=>String}
Makes a request and returns the body of the response. Example:
request_content = "{'location':'westus','tags':{'tag1':'val1','tag2':'val2'}}"
path = "/path"
= {
body: request_content,
query_params: {'api-version' => '2016-02-01'}
}
result = @client.make_request(:put, path, )
121 122 123 124 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 121 def make_request(method, path, = {}) result = make_request_with_http_info(method, path, ) result.body unless result.nil? end |
#make_request_async(method, path, options = {}) ⇒ Concurrent::Promise
Makes a request asynchronously.
146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 146 def make_request_async(method, path, = {}) fail ArgumentError, 'method is nil' if method.nil? fail ArgumentError, 'path is nil' if path.nil? request_url = [:base_url] || @base_url request_headers = @request_headers request_headers.merge!({'accept-language' => @accept_language}) unless @accept_language.nil? .merge!({headers: request_headers.merge([:headers] || {})}) .merge!({credentials: @credentials}) unless @credentials.nil? super(request_url, method, path, ) end |
#make_request_with_http_info(method, path, options = {}) ⇒ MsRestAzure::AzureOperationResponse
Makes a request and returns the operation response.
133 134 135 136 137 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 133 def make_request_with_http_info(method, path, = {}) result = make_request_async(method, path, ).value! result.body = result.response.body.to_s.empty? ? nil : JSON.load(result.response.body) result end |