Class: Azure::ARM::DevTestLabs::DevTestLabsClient

Inherits:
MsRestAzure::AzureServiceClient
  • Object
show all
Includes:
MsRestAzure, MsRestAzure::Serialization
Defined in:
lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb

Overview

A service client - single point of access to the REST API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(credentials, base_url = nil, options = nil) ⇒ DevTestLabsClient

Creates initializes a new instance of the DevTestLabsClient class.

Parameters:

  • credentials (MsRest::ServiceClientCredentials)

    credentials to authorize HTTP requests made by the service client.

  • base_url (String) (defaults to: nil)

    the base URI of the service.

  • options (Array) (defaults to: nil)

    filters to be applied to the HTTP requests.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 83

def initialize(credentials, base_url = nil, options = nil)
  super(credentials, options)
  @base_url = base_url || 'https://management.azure.com'

  fail ArgumentError, 'credentials is nil' if credentials.nil?
  fail ArgumentError, 'invalid type of credentials input parameter' unless credentials.is_a?(MsRest::ServiceClientCredentials)
  @credentials = credentials

  @lab_operations = LabOperations.new(self)
  @artifact_source_operations = ArtifactSourceOperations.new(self)
  @artifact_operations = ArtifactOperations.new(self)
  @cost_operations = CostOperations.new(self)
  @custom_image_operations = CustomImageOperations.new(self)
  @formula_operations = FormulaOperations.new(self)
  @gallery_image_operations = GalleryImageOperations.new(self)
  @policy_set = PolicySet.new(self)
  @policy_operations = PolicyOperations.new(self)
  @schedule_operations = ScheduleOperations.new(self)
  @virtual_machine = VirtualMachine.new(self)
  @virtual_network_operations = VirtualNetworkOperations.new(self)
  @api_version = '2016-05-15'
  @accept_language = 'en-US'
  @long_running_operation_retry_timeout = 30
  @generate_client_request_id = true
end

Instance Attribute Details

#accept_languageString

Returns Gets or sets the preferred language for the response.

Returns:

  • (String)

    Gets or sets the preferred language for the response.



27
28
29
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 27

def accept_language
  @accept_language
end

#api_versionString (readonly)

Returns Client API version.

Returns:

  • (String)

    Client API version.



21
22
23
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 21

def api_version
  @api_version
end

#artifact_operationsArtifactOperations (readonly)

Returns artifact_operations.

Returns:



48
49
50
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 48

def artifact_operations
  @artifact_operations
end

#artifact_source_operationsArtifactSourceOperations (readonly)

Returns artifact_source_operations.

Returns:



45
46
47
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 45

def artifact_source_operations
  @artifact_source_operations
end

#base_urlString

Returns the base URI of the service.

Returns:

  • (String)

    the base URI of the service.



15
16
17
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 15

def base_url
  @base_url
end

#cost_operationsCostOperations (readonly)

Returns cost_operations.

Returns:



51
52
53
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 51

def cost_operations
  @cost_operations
end

#credentialsObject

subscription.

Returns:

  • Subscription credentials which uniquely identify client



18
19
20
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 18

def credentials
  @credentials
end

#custom_image_operationsCustomImageOperations (readonly)

Returns custom_image_operations.

Returns:



54
55
56
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 54

def custom_image_operations
  @custom_image_operations
end

#formula_operationsFormulaOperations (readonly)

Returns formula_operations.

Returns:



57
58
59
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 57

def formula_operations
  @formula_operations
end

Returns gallery_image_operations.

Returns:



60
61
62
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 60

def gallery_image_operations
  @gallery_image_operations
end

#generate_client_request_idBoolean

is generated and included in each request. Default is true.

Returns:

  • (Boolean)

    When set to true a unique x-ms-client-request-id value



35
36
37
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 35

def generate_client_request_id
  @generate_client_request_id
end

#lab_operationsLabOperations (readonly)

Returns lab_operations.

Returns:



42
43
44
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 42

def lab_operations
  @lab_operations
end

#long_running_operation_retry_timeoutInteger

Running Operations. Default value is 30.

Returns:

  • (Integer)

    Gets or sets the retry timeout in seconds for Long



31
32
33
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 31

def long_running_operation_retry_timeout
  @long_running_operation_retry_timeout
end

#policy_operationsPolicyOperations (readonly)

Returns policy_operations.

Returns:



66
67
68
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 66

def policy_operations
  @policy_operations
end

#policy_setPolicySet (readonly)

Returns policy_set.

Returns:



63
64
65
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 63

def policy_set
  @policy_set
end

#schedule_operationsScheduleOperations (readonly)

Returns schedule_operations.

Returns:



69
70
71
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 69

def schedule_operations
  @schedule_operations
end

#subscription_idString

Returns The subscription ID.

Returns:

  • (String)

    The subscription ID.



24
25
26
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 24

def subscription_id
  @subscription_id
end

#virtual_machineVirtualMachine (readonly)

Returns virtual_machine.

Returns:



72
73
74
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 72

def virtual_machine
  @virtual_machine
end

#virtual_network_operationsVirtualNetworkOperations (readonly)

Returns virtual_network_operations.

Returns:



75
76
77
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 75

def virtual_network_operations
  @virtual_network_operations
end