Class: Azure::ARM::DevTestLabs::DevTestLabsClient
- Inherits:
-
MsRestAzure::AzureServiceClient
- Object
- MsRestAzure::AzureServiceClient
- Azure::ARM::DevTestLabs::DevTestLabsClient
- Includes:
- MsRestAzure, MsRestAzure::Serialization
- Defined in:
- lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb
Overview
A service client - single point of access to the REST API.
Instance Attribute Summary collapse
-
#accept_language ⇒ String
Gets or sets the preferred language for the response.
-
#api_version ⇒ String
readonly
Client API version.
-
#artifact_operations ⇒ ArtifactOperations
readonly
Artifact_operations.
-
#artifact_source_operations ⇒ ArtifactSourceOperations
readonly
Artifact_source_operations.
-
#base_url ⇒ String
The base URI of the service.
-
#cost_operations ⇒ CostOperations
readonly
Cost_operations.
-
#credentials ⇒ Object
subscription.
-
#custom_image_operations ⇒ CustomImageOperations
readonly
Custom_image_operations.
-
#formula_operations ⇒ FormulaOperations
readonly
Formula_operations.
-
#gallery_image_operations ⇒ GalleryImageOperations
readonly
Gallery_image_operations.
-
#generate_client_request_id ⇒ Boolean
is generated and included in each request.
-
#lab_operations ⇒ LabOperations
readonly
Lab_operations.
-
#long_running_operation_retry_timeout ⇒ Integer
Running Operations.
-
#policy_operations ⇒ PolicyOperations
readonly
Policy_operations.
-
#policy_set ⇒ PolicySet
readonly
Policy_set.
-
#schedule_operations ⇒ ScheduleOperations
readonly
Schedule_operations.
-
#subscription_id ⇒ String
The subscription ID.
-
#virtual_machine ⇒ VirtualMachine
readonly
Virtual_machine.
-
#virtual_network_operations ⇒ VirtualNetworkOperations
readonly
Virtual_network_operations.
Instance Method Summary collapse
-
#initialize(credentials, base_url = nil, options = nil) ⇒ DevTestLabsClient
constructor
Creates initializes a new instance of the DevTestLabsClient class.
Constructor Details
#initialize(credentials, base_url = nil, options = nil) ⇒ DevTestLabsClient
Creates initializes a new instance of the DevTestLabsClient class.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 83 def initialize(credentials, base_url = nil, = nil) super(credentials, ) @base_url = base_url || 'https://management.azure.com' fail ArgumentError, 'credentials is nil' if credentials.nil? fail ArgumentError, 'invalid type of credentials input parameter' unless credentials.is_a?(MsRest::ServiceClientCredentials) @credentials = credentials @lab_operations = LabOperations.new(self) @artifact_source_operations = ArtifactSourceOperations.new(self) @artifact_operations = ArtifactOperations.new(self) @cost_operations = CostOperations.new(self) @custom_image_operations = CustomImageOperations.new(self) @formula_operations = FormulaOperations.new(self) @gallery_image_operations = GalleryImageOperations.new(self) @policy_set = PolicySet.new(self) @policy_operations = PolicyOperations.new(self) @schedule_operations = ScheduleOperations.new(self) @virtual_machine = VirtualMachine.new(self) @virtual_network_operations = VirtualNetworkOperations.new(self) @api_version = '2016-05-15' @accept_language = 'en-US' @long_running_operation_retry_timeout = 30 @generate_client_request_id = true end |
Instance Attribute Details
#accept_language ⇒ String
Returns Gets or sets the preferred language for the response.
27 28 29 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 27 def accept_language @accept_language end |
#api_version ⇒ String (readonly)
Returns Client API version.
21 22 23 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 21 def api_version @api_version end |
#artifact_operations ⇒ ArtifactOperations (readonly)
Returns artifact_operations.
48 49 50 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 48 def artifact_operations @artifact_operations end |
#artifact_source_operations ⇒ ArtifactSourceOperations (readonly)
Returns artifact_source_operations.
45 46 47 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 45 def artifact_source_operations @artifact_source_operations end |
#base_url ⇒ String
Returns the base URI of the service.
15 16 17 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 15 def base_url @base_url end |
#cost_operations ⇒ CostOperations (readonly)
Returns cost_operations.
51 52 53 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 51 def cost_operations @cost_operations end |
#credentials ⇒ Object
subscription.
18 19 20 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 18 def credentials @credentials end |
#custom_image_operations ⇒ CustomImageOperations (readonly)
Returns custom_image_operations.
54 55 56 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 54 def custom_image_operations @custom_image_operations end |
#formula_operations ⇒ FormulaOperations (readonly)
Returns formula_operations.
57 58 59 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 57 def formula_operations @formula_operations end |
#gallery_image_operations ⇒ GalleryImageOperations (readonly)
Returns gallery_image_operations.
60 61 62 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 60 def gallery_image_operations @gallery_image_operations end |
#generate_client_request_id ⇒ Boolean
is generated and included in each request. Default is true.
35 36 37 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 35 def generate_client_request_id @generate_client_request_id end |
#lab_operations ⇒ LabOperations (readonly)
Returns lab_operations.
42 43 44 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 42 def lab_operations @lab_operations end |
#long_running_operation_retry_timeout ⇒ Integer
Running Operations. Default value is 30.
31 32 33 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 31 def long_running_operation_retry_timeout @long_running_operation_retry_timeout end |
#policy_operations ⇒ PolicyOperations (readonly)
Returns policy_operations.
66 67 68 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 66 def policy_operations @policy_operations end |
#policy_set ⇒ PolicySet (readonly)
Returns policy_set.
63 64 65 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 63 def policy_set @policy_set end |
#schedule_operations ⇒ ScheduleOperations (readonly)
Returns schedule_operations.
69 70 71 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 69 def schedule_operations @schedule_operations end |
#subscription_id ⇒ String
Returns The subscription ID.
24 25 26 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 24 def subscription_id @subscription_id end |
#virtual_machine ⇒ VirtualMachine (readonly)
Returns virtual_machine.
72 73 74 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 72 def virtual_machine @virtual_machine end |
#virtual_network_operations ⇒ VirtualNetworkOperations (readonly)
Returns virtual_network_operations.
75 76 77 |
# File 'lib/generated/azure_mgmt_devtestlabs/dev_test_labs_client.rb', line 75 def virtual_network_operations @virtual_network_operations end |