Class: Azure::ARM::DevTestLabs::FormulaOperations

Inherits:
Object
  • Object
show all
Includes:
Models, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/formula_operations.rb

Overview

The DevTest Labs Client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ FormulaOperations

Creates and initializes a new instance of the FormulaOperations class.

Parameters:

  • service class for accessing basic functionality.



18
19
20
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 18

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientDevTestLabsClient (readonly)

Returns reference to the DevTestLabsClient.

Returns:

  • reference to the DevTestLabsClient



23
24
25
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 23

def client
  @client
end

Instance Method Details

#begin_create_or_update_resource(resource_group_name, lab_name, name, formula, custom_headers = nil) ⇒ Formula

Create or replace an existing Formula. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



319
320
321
322
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 319

def begin_create_or_update_resource(resource_group_name, lab_name, name, formula, custom_headers = nil)
  response = begin_create_or_update_resource_async(resource_group_name, lab_name, name, formula, custom_headers).value!
  response.body unless response.nil?
end

#begin_create_or_update_resource_async(resource_group_name, lab_name, name, formula, custom_headers = nil) ⇒ Concurrent::Promise

Create or replace an existing Formula. This operation can take a while to complete.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 354

def begin_create_or_update_resource_async(resource_group_name, lab_name, name, formula, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'formula is nil' if formula.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = Formula.mapper()
  request_content = @client.serialize(request_mapper,  formula, 'formula')
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/formulas/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :put, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 201
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Formula.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end
    # Deserialize Response
    if status_code == 201
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Formula.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#begin_create_or_update_resource_with_http_info(resource_group_name, lab_name, name, formula, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Create or replace an existing Formula. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



337
338
339
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 337

def begin_create_or_update_resource_with_http_info(resource_group_name, lab_name, name, formula, custom_headers = nil)
  begin_create_or_update_resource_async(resource_group_name, lab_name, name, formula, custom_headers).value!
end

#create_or_update_resource(resource_group_name, lab_name, name, formula, custom_headers = nil) ⇒ Formula

Create or replace an existing Formula. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



272
273
274
275
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 272

def create_or_update_resource(resource_group_name, lab_name, name, formula, custom_headers = nil)
  response = create_or_update_resource_async(resource_group_name, lab_name, name, formula, custom_headers).value!
  response.body unless response.nil?
end

#create_or_update_resource_async(resource_group_name, lab_name, name, formula, custom_headers = nil) ⇒ Concurrent::Promise

will be added to the HTTP request.

response.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • promise which provides async access to http



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 288

def create_or_update_resource_async(resource_group_name, lab_name, name, formula, custom_headers = nil)
  # Send request
  promise = begin_create_or_update_resource_async(resource_group_name, lab_name, name, formula, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
      result_mapper = Formula.mapper()
      parsed_response = @client.deserialize(result_mapper, parsed_response, 'parsed_response')
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#delete_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object

Delete formula.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • (defaults to: nil)

    A hash of custom headers that



440
441
442
443
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 440

def delete_resource(resource_group_name, lab_name, name, custom_headers = nil)
  response = delete_resource_async(resource_group_name, lab_name, name, custom_headers).value!
  nil
end

#delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Delete formula.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 471

def delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/formulas/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :delete, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 204
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#delete_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Delete formula.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



456
457
458
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 456

def delete_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil)
  delete_resource_async(resource_group_name, lab_name, name, custom_headers).value!
end

#get_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Formula

Get formula.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



172
173
174
175
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 172

def get_resource(resource_group_name, lab_name, name, custom_headers = nil)
  response = get_resource_async(resource_group_name, lab_name, name, custom_headers).value!
  response.body unless response.nil?
end

#get_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Get formula.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 203

def get_resource_async(resource_group_name, lab_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/formulas/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Formula.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Get formula.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the formula.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



188
189
190
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 188

def get_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil)
  get_resource_async(resource_group_name, lab_name, name, custom_headers).value!
end

#list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Array<Formula>

List formulas in a given lab.

operation. OData notation. will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



67
68
69
70
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 67

def list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  first_page = list_as_lazy(resource_group_name, lab_name, filter, top, order_by, custom_headers)
  first_page.get_all_items
end

#list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ ResponseWithContinuationFormula

List formulas in a given lab.

operation. OData notation. will be added to the HTTP request.

of the response.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • which provide lazy access to pages



41
42
43
44
45
46
47
48
49
50
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 41

def list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  response = list_async(resource_group_name, lab_name, filter, top, order_by, custom_headers).value!
  unless response.nil?
    page = response.body
    page.next_method = Proc.new do |next_link|
      list_next_async(next_link, custom_headers)
    end
    page
  end
end

#list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Concurrent::Promise

List formulas in a given lab.

operation. OData notation. to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 106

def list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/formulas'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name},
      query_params: {'$filter' => filter,'$top' => top,'$orderBy' => order_by,'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = ResponseWithContinuationFormula.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationFormula

List formulas in a given lab.

call to List operation. will be added to the HTTP request.

Parameters:

  • The NextLink from the previous successful

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



527
528
529
530
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 527

def list_next(next_page_link, custom_headers = nil)
  response = list_next_async(next_page_link, custom_headers).value!
  response.body unless response.nil?
end

#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise

List formulas in a given lab.

call to List operation. to the HTTP request.

Parameters:

  • The NextLink from the previous successful

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 556

def list_next_async(next_page_link, custom_headers = nil)
  fail ArgumentError, 'next_page_link is nil' if next_page_link.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '{nextLink}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      skip_encoding_path_params: {'nextLink' => next_page_link},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = ResponseWithContinuationFormula.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List formulas in a given lab.

call to List operation. will be added to the HTTP request.

Parameters:

  • The NextLink from the previous successful

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



542
543
544
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 542

def list_next_with_http_info(next_page_link, custom_headers = nil)
  list_next_async(next_page_link, custom_headers).value!
end

#list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List formulas in a given lab.

operation. OData notation. will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



87
88
89
# File 'lib/generated/azure_mgmt_devtestlabs/formula_operations.rb', line 87

def list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  list_async(resource_group_name, lab_name, filter, top, order_by, custom_headers).value!
end