Class: Azure::ARM::DevTestLabs::GalleryImageOperations
- Inherits:
-
Object
- Object
- Azure::ARM::DevTestLabs::GalleryImageOperations
- Includes:
- Models, MsRestAzure
- Defined in:
- lib/generated/azure_mgmt_devtestlabs/gallery_image_operations.rb
Overview
The DevTest Labs Client.
Instance Attribute Summary collapse
-
#client ⇒ DevTestLabsClient
readonly
Reference to the DevTestLabsClient.
Instance Method Summary collapse
-
#initialize(client) ⇒ GalleryImageOperations
constructor
Creates and initializes a new instance of the GalleryImageOperations class.
-
#list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Array<GalleryImage>
List gallery images in a given lab.
-
#list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ ResponseWithContinuationGalleryImage
List gallery images in a given lab.
-
#list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Concurrent::Promise
List gallery images in a given lab.
-
#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationGalleryImage
List gallery images in a given lab.
-
#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise
List gallery images in a given lab.
-
#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List gallery images in a given lab.
-
#list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List gallery images in a given lab.
Constructor Details
#initialize(client) ⇒ GalleryImageOperations
Creates and initializes a new instance of the GalleryImageOperations class.
18 19 20 |
# File 'lib/generated/azure_mgmt_devtestlabs/gallery_image_operations.rb', line 18 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ DevTestLabsClient (readonly)
Returns reference to the DevTestLabsClient.
23 24 25 |
# File 'lib/generated/azure_mgmt_devtestlabs/gallery_image_operations.rb', line 23 def client @client end |
Instance Method Details
#list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Array<GalleryImage>
List gallery images in a given lab.
operation. OData notation. will be added to the HTTP request.
67 68 69 70 |
# File 'lib/generated/azure_mgmt_devtestlabs/gallery_image_operations.rb', line 67 def list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) first_page = list_as_lazy(resource_group_name, lab_name, filter, top, order_by, custom_headers) first_page.get_all_items end |
#list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ ResponseWithContinuationGalleryImage
List gallery images in a given lab.
operation. OData notation. will be added to the HTTP request.
pages of the response.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/generated/azure_mgmt_devtestlabs/gallery_image_operations.rb', line 41 def list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) response = list_async(resource_group_name, lab_name, filter, top, order_by, custom_headers).value! unless response.nil? page = response.body page.next_method = Proc.new do |next_link| list_next_async(next_link, custom_headers) end page end end |
#list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Concurrent::Promise
List gallery images in a given lab.
operation. OData notation. to the HTTP request.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/generated/azure_mgmt_devtestlabs/gallery_image_operations.rb', line 106 def list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'lab_name is nil' if lab_name.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/galleryimages' = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name}, query_params: {'$filter' => filter,'$top' => top,'$orderBy' => order_by,'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}) } request_url = @base_url || @client.base_url request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, ) promise = request.run_promise do |req| @client.credentials.sign_request(req) unless @client.credentials.nil? end promise = promise.then do |http_response| status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(request, http_response, error_model) end # Create Result result = MsRestAzure::AzureOperationResponse.new(request, http_response) result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = ResponseWithContinuationGalleryImage.mapper() result.body = @client.deserialize(result_mapper, parsed_response, 'result.body') rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationGalleryImage
List gallery images in a given lab.
call to List operation. will be added to the HTTP request.
171 172 173 174 |
# File 'lib/generated/azure_mgmt_devtestlabs/gallery_image_operations.rb', line 171 def list_next(next_page_link, custom_headers = nil) response = list_next_async(next_page_link, custom_headers).value! response.body unless response.nil? end |
#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise
List gallery images in a given lab.
call to List operation. to the HTTP request.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/generated/azure_mgmt_devtestlabs/gallery_image_operations.rb', line 200 def list_next_async(next_page_link, custom_headers = nil) fail ArgumentError, 'next_page_link is nil' if next_page_link.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{nextLink}' = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'nextLink' => next_page_link}, headers: request_headers.merge(custom_headers || {}) } request_url = @base_url || @client.base_url request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, ) promise = request.run_promise do |req| @client.credentials.sign_request(req) unless @client.credentials.nil? end promise = promise.then do |http_response| status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(request, http_response, error_model) end # Create Result result = MsRestAzure::AzureOperationResponse.new(request, http_response) result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = ResponseWithContinuationGalleryImage.mapper() result.body = @client.deserialize(result_mapper, parsed_response, 'result.body') rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List gallery images in a given lab.
call to List operation. will be added to the HTTP request.
186 187 188 |
# File 'lib/generated/azure_mgmt_devtestlabs/gallery_image_operations.rb', line 186 def list_next_with_http_info(next_page_link, custom_headers = nil) list_next_async(next_page_link, custom_headers).value! end |
#list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List gallery images in a given lab.
operation. OData notation. will be added to the HTTP request.
87 88 89 |
# File 'lib/generated/azure_mgmt_devtestlabs/gallery_image_operations.rb', line 87 def list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) list_async(resource_group_name, lab_name, filter, top, order_by, custom_headers).value! end |