Class: Azure::ARM::DevTestLabs::Models::CustomImagePropertiesCustom
- Inherits:
-
Object
- Object
- Azure::ARM::DevTestLabs::Models::CustomImagePropertiesCustom
- Includes:
- MsRestAzure
- Defined in:
- lib/generated/azure_mgmt_devtestlabs/models/custom_image_properties_custom.rb
Overview
Properties for creating a custom image from a VHD.
Instance Attribute Summary collapse
-
#image_name ⇒ String
The image name.
-
#os_type ⇒ CustomImageOsType
values include: ‘Windows’, ‘Linux’, ‘None’.
-
#sys_prep ⇒ Boolean
Indicates whether sysprep has been run on the VHD.
Class Method Summary collapse
-
.mapper ⇒ Object
Mapper for CustomImagePropertiesCustom class as Ruby Hash.
Instance Attribute Details
#image_name ⇒ String
Returns The image name.
16 17 18 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image_properties_custom.rb', line 16 def image_name @image_name end |
#os_type ⇒ CustomImageOsType
values include: ‘Windows’, ‘Linux’, ‘None’
23 24 25 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image_properties_custom.rb', line 23 def os_type @os_type end |
#sys_prep ⇒ Boolean
Returns Indicates whether sysprep has been run on the VHD.
19 20 21 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image_properties_custom.rb', line 19 def sys_prep @sys_prep end |
Class Method Details
.mapper ⇒ Object
Mapper for CustomImagePropertiesCustom class as Ruby Hash. This will be used for serialization/deserialization.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/generated/azure_mgmt_devtestlabs/models/custom_image_properties_custom.rb', line 30 def self.mapper() { required: false, serialized_name: 'CustomImagePropertiesCustom', type: { name: 'Composite', class_name: 'CustomImagePropertiesCustom', model_properties: { image_name: { required: false, serialized_name: 'imageName', type: { name: 'String' } }, sys_prep: { required: false, serialized_name: 'sysPrep', type: { name: 'Boolean' } }, os_type: { required: false, serialized_name: 'osType', type: { name: 'String' } } } } } end |