Class: Azure::ARM::DevTestLabs::Models::LabVirtualMachine

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb

Overview

A virtual machine.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#artifact_deployment_statusArtifactDeploymentStatusProperties

status for the virtual machine.

Returns:

  • The artifact deployment



76
77
78
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 76

def artifact_deployment_status
  @artifact_deployment_status
end

#artifactsArray<ArtifactInstallProperties>

installed on the virtual machine.

Returns:

  • The artifacts to be



72
73
74
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 72

def artifacts
  @artifacts
end

#compute_idString

virtual machine.

Returns:

  • The resource identifier (Microsoft.Compute) of the



31
32
33
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 31

def compute_id
  @compute_id
end

#created_by_userString

Returns The email address of creator of the virtual machine.

Returns:

  • The email address of creator of the virtual machine.



27
28
29
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 27

def created_by_user
  @created_by_user
end

#created_by_user_idString

machine.

Returns:

  • The object identifier of the creator of the virtual



24
25
26
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 24

def created_by_user_id
  @created_by_user_id
end

#custom_image_idString

Returns The custom image identifier of the virtual machine.

Returns:

  • The custom image identifier of the virtual machine.



34
35
36
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 34

def custom_image_id
  @custom_image_id
end

#disallow_public_ip_addressBoolean

created without a public IP address.

Returns:

  • Indicates whether the virtual machine is to be



68
69
70
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 68

def disallow_public_ip_address
  @disallow_public_ip_address
end

#fqdnString

machine.

Returns:

  • The fully-qualified domain name of the virtual



57
58
59
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 57

def fqdn
  @fqdn
end

reference of the virtual machine.

Returns:

  • The Microsoft Azure Marketplace image



80
81
82
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 80

def gallery_image_reference
  @gallery_image_reference
end

#idString

Returns The identifier of the resource.

Returns:

  • The identifier of the resource.



89
90
91
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 89

def id
  @id
end

#is_authentication_with_ssh_keyBoolean

an SSH key for authentication.

Returns:

  • A value indicating whether this virtual machine uses



53
54
55
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 53

def is_authentication_with_ssh_key
  @is_authentication_with_ssh_key
end

#lab_subnet_nameString

Returns The lab subnet name of the virtual machine.

Returns:

  • The lab subnet name of the virtual machine.



60
61
62
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 60

def lab_subnet_name
  @lab_subnet_name
end

#lab_virtual_network_idString

machine.

Returns:

  • The lab virtual network identifier of the virtual



64
65
66
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 64

def lab_virtual_network_id
  @lab_virtual_network_id
end

#locationString

Returns The location of the resource.

Returns:

  • The location of the resource.



98
99
100
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 98

def location
  @location
end

#nameString

Returns The name of the resource.

Returns:

  • The name of the resource.



92
93
94
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 92

def name
  @name
end

#notesString

Returns The notes of the virtual machine.

Returns:

  • The notes of the virtual machine.



16
17
18
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 16

def notes
  @notes
end

#os_typeString

Returns The OS type of the virtual machine.

Returns:

  • The OS type of the virtual machine.



37
38
39
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 37

def os_type
  @os_type
end

#owner_object_idString

machine.

Returns:

  • The object identifier of the owner of the virtual



20
21
22
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 20

def owner_object_id
  @owner_object_id
end

#passwordString

Returns The password of the virtual machine administrator.

Returns:

  • The password of the virtual machine administrator.



46
47
48
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 46

def password
  @password
end

#provisioning_stateString

Returns The provisioning status of the resource.

Returns:

  • The provisioning status of the resource.



83
84
85
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 83

def provisioning_state
  @provisioning_state
end

#sizeString

Returns The size of the virtual machine.

Returns:

  • The size of the virtual machine.



40
41
42
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 40

def size
  @size
end

#ssh_keyString

Returns The SSH key of the virtual machine administrator.

Returns:

  • The SSH key of the virtual machine administrator.



49
50
51
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 49

def ssh_key
  @ssh_key
end

#tagsHash{String => String}

Returns The tags of the resource.

Returns:

  • The tags of the resource.



101
102
103
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 101

def tags
  @tags
end

#typeString

Returns The type of the resource.

Returns:

  • The type of the resource.



95
96
97
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 95

def type
  @type
end

#unique_identifierString

Returns The unique immutable identifier of a resource (Guid).

Returns:

  • The unique immutable identifier of a resource (Guid).



86
87
88
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 86

def unique_identifier
  @unique_identifier
end

#user_nameString

Returns The user name of the virtual machine.

Returns:

  • The user name of the virtual machine.



43
44
45
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 43

def user_name
  @user_name
end

Class Method Details

.mapperObject

Mapper for LabVirtualMachine class as Ruby Hash. This will be used for serialization/deserialization.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/generated/azure_mgmt_devtestlabs/models/lab_virtual_machine.rb', line 108

def self.mapper()
  {
    required: false,
    serialized_name: 'LabVirtualMachine',
    type: {
      name: 'Composite',
      class_name: 'LabVirtualMachine',
      model_properties: {
        notes: {
          required: false,
          serialized_name: 'properties.notes',
          type: {
            name: 'String'
          }
        },
        owner_object_id: {
          required: false,
          serialized_name: 'properties.ownerObjectId',
          type: {
            name: 'String'
          }
        },
        created_by_user_id: {
          required: false,
          serialized_name: 'properties.createdByUserId',
          type: {
            name: 'String'
          }
        },
        created_by_user: {
          required: false,
          serialized_name: 'properties.createdByUser',
          type: {
            name: 'String'
          }
        },
        compute_id: {
          required: false,
          serialized_name: 'properties.computeId',
          type: {
            name: 'String'
          }
        },
        custom_image_id: {
          required: false,
          serialized_name: 'properties.customImageId',
          type: {
            name: 'String'
          }
        },
        os_type: {
          required: false,
          serialized_name: 'properties.osType',
          type: {
            name: 'String'
          }
        },
        size: {
          required: false,
          serialized_name: 'properties.size',
          type: {
            name: 'String'
          }
        },
        user_name: {
          required: false,
          serialized_name: 'properties.userName',
          type: {
            name: 'String'
          }
        },
        password: {
          required: false,
          serialized_name: 'properties.password',
          type: {
            name: 'String'
          }
        },
        ssh_key: {
          required: false,
          serialized_name: 'properties.sshKey',
          type: {
            name: 'String'
          }
        },
        is_authentication_with_ssh_key: {
          required: false,
          serialized_name: 'properties.isAuthenticationWithSshKey',
          type: {
            name: 'Boolean'
          }
        },
        fqdn: {
          required: false,
          serialized_name: 'properties.fqdn',
          type: {
            name: 'String'
          }
        },
        lab_subnet_name: {
          required: false,
          serialized_name: 'properties.labSubnetName',
          type: {
            name: 'String'
          }
        },
        lab_virtual_network_id: {
          required: false,
          serialized_name: 'properties.labVirtualNetworkId',
          type: {
            name: 'String'
          }
        },
        disallow_public_ip_address: {
          required: false,
          serialized_name: 'properties.disallowPublicIpAddress',
          type: {
            name: 'Boolean'
          }
        },
        artifacts: {
          required: false,
          serialized_name: 'properties.artifacts',
          type: {
            name: 'Sequence',
            element: {
                required: false,
                serialized_name: 'ArtifactInstallPropertiesElementType',
                type: {
                  name: 'Composite',
                  class_name: 'ArtifactInstallProperties'
                }
            }
          }
        },
        artifact_deployment_status: {
          required: false,
          serialized_name: 'properties.artifactDeploymentStatus',
          type: {
            name: 'Composite',
            class_name: 'ArtifactDeploymentStatusProperties'
          }
        },
        gallery_image_reference: {
          required: false,
          serialized_name: 'properties.galleryImageReference',
          type: {
            name: 'Composite',
            class_name: 'GalleryImageReference'
          }
        },
        provisioning_state: {
          required: false,
          serialized_name: 'properties.provisioningState',
          type: {
            name: 'String'
          }
        },
        unique_identifier: {
          required: false,
          serialized_name: 'properties.uniqueIdentifier',
          type: {
            name: 'String'
          }
        },
        id: {
          required: false,
          serialized_name: 'id',
          type: {
            name: 'String'
          }
        },
        name: {
          required: false,
          serialized_name: 'name',
          type: {
            name: 'String'
          }
        },
        type: {
          required: false,
          serialized_name: 'type',
          type: {
            name: 'String'
          }
        },
        location: {
          required: false,
          serialized_name: 'location',
          type: {
            name: 'String'
          }
        },
        tags: {
          required: false,
          serialized_name: 'tags',
          type: {
            name: 'Dictionary',
            value: {
                required: false,
                serialized_name: 'StringElementType',
                type: {
                  name: 'String'
                }
            }
          }
        }
      }
    }
  }
end