Class: Azure::ARM::DevTestLabs::ScheduleOperations

Inherits:
Object
  • Object
show all
Includes:
Models, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb

Overview

The DevTest Labs Client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ ScheduleOperations

Creates and initializes a new instance of the ScheduleOperations class.

Parameters:

  • client

    service class for accessing basic functionality.



18
19
20
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 18

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientDevTestLabsClient (readonly)

Returns reference to the DevTestLabsClient.

Returns:



23
24
25
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 23

def client
  @client
end

Instance Method Details

#begin_execute(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object

Execute a schedule. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



628
629
630
631
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 628

def begin_execute(resource_group_name, lab_name, name, custom_headers = nil)
  response = begin_execute_async(resource_group_name, lab_name, name, custom_headers).value!
  nil
end

#begin_execute_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Execute a schedule. This operation can take a while to complete.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 659

def begin_execute_async(resource_group_name, lab_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/schedules/{name}/execute'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :post, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 202
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#begin_execute_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Execute a schedule. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



644
645
646
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 644

def begin_execute_with_http_info(resource_group_name, lab_name, name, custom_headers = nil)
  begin_execute_async(resource_group_name, lab_name, name, custom_headers).value!
end

#create_or_update_resource(resource_group_name, lab_name, name, schedule, custom_headers = nil) ⇒ Schedule

Create or replace an existing schedule.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • schedule (Schedule)
  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:



271
272
273
274
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 271

def create_or_update_resource(resource_group_name, lab_name, name, schedule, custom_headers = nil)
  response = create_or_update_resource_async(resource_group_name, lab_name, name, schedule, custom_headers).value!
  response.body unless response.nil?
end

#create_or_update_resource_async(resource_group_name, lab_name, name, schedule, custom_headers = nil) ⇒ Concurrent::Promise

Create or replace an existing schedule.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • schedule (Schedule)
  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 304

def create_or_update_resource_async(resource_group_name, lab_name, name, schedule, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'schedule is nil' if schedule.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = Schedule.mapper()
  request_content = @client.serialize(request_mapper,  schedule, 'schedule')
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/schedules/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :put, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 201
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Schedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end
    # Deserialize Response
    if status_code == 201
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Schedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#create_or_update_resource_with_http_info(resource_group_name, lab_name, name, schedule, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Create or replace an existing schedule.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • schedule (Schedule)
  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



288
289
290
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 288

def create_or_update_resource_with_http_info(resource_group_name, lab_name, name, schedule, custom_headers = nil)
  create_or_update_resource_async(resource_group_name, lab_name, name, schedule, custom_headers).value!
end

#delete_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object

Delete schedule.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



390
391
392
393
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 390

def delete_resource(resource_group_name, lab_name, name, custom_headers = nil)
  response = delete_resource_async(resource_group_name, lab_name, name, custom_headers).value!
  nil
end

#delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Delete schedule.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 421

def delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/schedules/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :delete, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 204
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#delete_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Delete schedule.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



406
407
408
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 406

def delete_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil)
  delete_resource_async(resource_group_name, lab_name, name, custom_headers).value!
end

#execute(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object

Execute a schedule. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that



587
588
589
590
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 587

def execute(resource_group_name, lab_name, name, custom_headers = nil)
  response = execute_async(resource_group_name, lab_name, name, custom_headers).value!
  nil
end

#execute_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

will be added to the HTTP request.

response.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Concurrent::Promise)

    promise which provides async access to http



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 602

def execute_async(resource_group_name, lab_name, name, custom_headers = nil)
  # Send request
  promise = begin_execute_async(resource_group_name, lab_name, name, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#get_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Schedule

Get schedule.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:



172
173
174
175
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 172

def get_resource(resource_group_name, lab_name, name, custom_headers = nil)
  response = get_resource_async(resource_group_name, lab_name, name, custom_headers).value!
  response.body unless response.nil?
end

#get_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Get schedule.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 203

def get_resource_async(resource_group_name, lab_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/schedules/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Schedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Get schedule.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



188
189
190
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 188

def get_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil)
  get_resource_async(resource_group_name, lab_name, name, custom_headers).value!
end

#list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Array<Schedule>

List schedules in a given lab.

operation. OData notation. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • filter (String) (defaults to: nil)

    The filter to apply on the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • order_by (String) (defaults to: nil)

    The ordering expression for the results, using

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Array<Schedule>)

    operation results.



67
68
69
70
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 67

def list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  first_page = list_as_lazy(resource_group_name, lab_name, filter, top, order_by, custom_headers)
  first_page.get_all_items
end

#list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ ResponseWithContinuationSchedule

List schedules in a given lab.

operation. OData notation. will be added to the HTTP request.

pages of the response.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • filter (String) (defaults to: nil)

    The filter to apply on the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • order_by (String) (defaults to: nil)

    The ordering expression for the results, using

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:



41
42
43
44
45
46
47
48
49
50
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 41

def list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  response = list_async(resource_group_name, lab_name, filter, top, order_by, custom_headers).value!
  unless response.nil?
    page = response.body
    page.next_method = Proc.new do |next_link|
      list_next_async(next_link, custom_headers)
    end
    page
  end
end

#list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Concurrent::Promise

List schedules in a given lab.

operation. OData notation. to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • filter (String) (defaults to: nil)

    The filter to apply on the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • order_by (String) (defaults to: nil)

    The ordering expression for the results, using

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 106

def list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/schedules'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name},
      query_params: {'$filter' => filter,'$top' => top,'$orderBy' => order_by,'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = ResponseWithContinuationSchedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationSchedule

List schedules in a given lab.

call to List operation. will be added to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:



715
716
717
718
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 715

def list_next(next_page_link, custom_headers = nil)
  response = list_next_async(next_page_link, custom_headers).value!
  response.body unless response.nil?
end

#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise

List schedules in a given lab.

call to List operation. to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 744

def list_next_async(next_page_link, custom_headers = nil)
  fail ArgumentError, 'next_page_link is nil' if next_page_link.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '{nextLink}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      skip_encoding_path_params: {'nextLink' => next_page_link},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = ResponseWithContinuationSchedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List schedules in a given lab.

call to List operation. will be added to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



730
731
732
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 730

def list_next_with_http_info(next_page_link, custom_headers = nil)
  list_next_async(next_page_link, custom_headers).value!
end

#list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List schedules in a given lab.

operation. OData notation. will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • filter (String) (defaults to: nil)

    The filter to apply on the operation.

  • top (Integer) (defaults to: nil)

    The maximum number of resources to return from the

  • order_by (String) (defaults to: nil)

    The ordering expression for the results, using

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



87
88
89
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 87

def list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  list_async(resource_group_name, lab_name, filter, top, order_by, custom_headers).value!
end

#patch_resource(resource_group_name, lab_name, name, schedule, custom_headers = nil) ⇒ Schedule

Modify properties of schedules.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • schedule (Schedule)
  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:



479
480
481
482
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 479

def patch_resource(resource_group_name, lab_name, name, schedule, custom_headers = nil)
  response = patch_resource_async(resource_group_name, lab_name, name, schedule, custom_headers).value!
  response.body unless response.nil?
end

#patch_resource_async(resource_group_name, lab_name, name, schedule, custom_headers = nil) ⇒ Concurrent::Promise

Modify properties of schedules.

to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • schedule (Schedule)
  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 512

def patch_resource_async(resource_group_name, lab_name, name, schedule, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'schedule is nil' if schedule.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = Schedule.mapper()
  request_content = @client.serialize(request_mapper,  schedule, 'schedule')
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/schedules/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :patch, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Schedule.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#patch_resource_with_http_info(resource_group_name, lab_name, name, schedule, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Modify properties of schedules.

will be added to the HTTP request.

Parameters:

  • resource_group_name (String)

    The name of the resource group.

  • lab_name (String)

    The name of the lab.

  • name (String)

    The name of the schedule.

  • schedule (Schedule)
  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



496
497
498
# File 'lib/generated/azure_mgmt_devtestlabs/schedule_operations.rb', line 496

def patch_resource_with_http_info(resource_group_name, lab_name, name, schedule, custom_headers = nil)
  patch_resource_async(resource_group_name, lab_name, name, schedule, custom_headers).value!
end