Class: Azure::ARM::DevTestLabs::VirtualMachine

Inherits:
Object
  • Object
show all
Includes:
Models, MsRestAzure
Defined in:
lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb

Overview

The DevTest Labs Client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ VirtualMachine

Creates and initializes a new instance of the VirtualMachine class.

Parameters:

  • service class for accessing basic functionality.



18
19
20
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 18

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientDevTestLabsClient (readonly)

Returns reference to the DevTestLabsClient.

Returns:

  • reference to the DevTestLabsClient



23
24
25
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 23

def client
  @client
end

Instance Method Details

#apply_artifacts(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers = nil) ⇒ Object

Apply artifacts to Lab VM. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that



678
679
680
681
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 678

def apply_artifacts(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers = nil)
  response = apply_artifacts_async(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers).value!
  nil
end

#apply_artifacts_async(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers = nil) ⇒ Concurrent::Promise

will be added to the HTTP request.

response.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • promise which provides async access to http



694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 694

def apply_artifacts_async(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers = nil)
  # Send request
  promise = begin_apply_artifacts_async(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#begin_apply_artifacts(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers = nil) ⇒ Object

Apply artifacts to Lab VM. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that



721
722
723
724
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 721

def begin_apply_artifacts(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers = nil)
  response = begin_apply_artifacts_async(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers).value!
  nil
end

#begin_apply_artifacts_async(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers = nil) ⇒ Concurrent::Promise

Apply artifacts to Lab VM. This operation can take a while to complete.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 754

def begin_apply_artifacts_async(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'apply_artifacts_request is nil' if apply_artifacts_request.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = ApplyArtifactsRequest.mapper()
  request_content = @client.serialize(request_mapper,  apply_artifacts_request, 'apply_artifacts_request')
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{name}/applyArtifacts'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :post, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 202
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#begin_apply_artifacts_with_http_info(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Apply artifacts to Lab VM. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



738
739
740
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 738

def begin_apply_artifacts_with_http_info(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers = nil)
  begin_apply_artifacts_async(resource_group_name, lab_name, name, apply_artifacts_request, custom_headers).value!
end

#begin_create_or_update_resource(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil) ⇒ LabVirtualMachine

Create or replace an existing Virtual Machine. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



319
320
321
322
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 319

def begin_create_or_update_resource(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil)
  response = begin_create_or_update_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers).value!
  response.body unless response.nil?
end

#begin_create_or_update_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil) ⇒ Concurrent::Promise

Create or replace an existing Virtual Machine. This operation can take a while to complete.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 354

def begin_create_or_update_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'lab_virtual_machine is nil' if lab_virtual_machine.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = LabVirtualMachine.mapper()
  request_content = @client.serialize(request_mapper,  lab_virtual_machine, 'lab_virtual_machine')
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :put, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 201
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = LabVirtualMachine.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end
    # Deserialize Response
    if status_code == 201
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = LabVirtualMachine.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#begin_create_or_update_resource_with_http_info(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Create or replace an existing Virtual Machine. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



337
338
339
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 337

def begin_create_or_update_resource_with_http_info(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil)
  begin_create_or_update_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers).value!
end

#begin_delete_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object

Delete virtual machine. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that



480
481
482
483
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 480

def begin_delete_resource(resource_group_name, lab_name, name, custom_headers = nil)
  response = begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers).value!
  nil
end

#begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Delete virtual machine. This operation can take a while to complete.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 511

def begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :delete, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 202 || status_code == 204
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#begin_delete_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Delete virtual machine. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



496
497
498
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 496

def begin_delete_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil)
  begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers).value!
end

#begin_start(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object

Start a Lab VM. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that



860
861
862
863
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 860

def begin_start(resource_group_name, lab_name, name, custom_headers = nil)
  response = begin_start_async(resource_group_name, lab_name, name, custom_headers).value!
  nil
end

#begin_start_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Start a Lab VM. This operation can take a while to complete.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 891

def begin_start_async(resource_group_name, lab_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{name}/start'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :post, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 202
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#begin_start_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Start a Lab VM. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



876
877
878
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 876

def begin_start_with_http_info(resource_group_name, lab_name, name, custom_headers = nil)
  begin_start_async(resource_group_name, lab_name, name, custom_headers).value!
end

#begin_stop(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object

Stop a Lab VM. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that



987
988
989
990
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 987

def begin_stop(resource_group_name, lab_name, name, custom_headers = nil)
  response = begin_stop_async(resource_group_name, lab_name, name, custom_headers).value!
  nil
end

#begin_stop_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Stop a Lab VM. This operation can take a while to complete.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 1018

def begin_stop_async(resource_group_name, lab_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{name}/stop'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :post, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 202
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?

    result
  end

  promise.execute
end

#begin_stop_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Stop a Lab VM. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



1003
1004
1005
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 1003

def begin_stop_with_http_info(resource_group_name, lab_name, name, custom_headers = nil)
  begin_stop_async(resource_group_name, lab_name, name, custom_headers).value!
end

#create_or_update_resource(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil) ⇒ LabVirtualMachine

Create or replace an existing Virtual Machine. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



272
273
274
275
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 272

def create_or_update_resource(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil)
  response = create_or_update_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers).value!
  response.body unless response.nil?
end

#create_or_update_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil) ⇒ Concurrent::Promise

will be added to the HTTP request.

response.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • promise which provides async access to http



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 288

def create_or_update_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil)
  # Send request
  promise = begin_create_or_update_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
      result_mapper = LabVirtualMachine.mapper()
      parsed_response = @client.deserialize(result_mapper, parsed_response, 'parsed_response')
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#delete_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object

Delete virtual machine. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that



439
440
441
442
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 439

def delete_resource(resource_group_name, lab_name, name, custom_headers = nil)
  response = delete_resource_async(resource_group_name, lab_name, name, custom_headers).value!
  nil
end

#delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

will be added to the HTTP request.

response.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • promise which provides async access to http



454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 454

def delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil)
  # Send request
  promise = begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#get_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ LabVirtualMachine

Get virtual machine.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



172
173
174
175
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 172

def get_resource(resource_group_name, lab_name, name, custom_headers = nil)
  response = get_resource_async(resource_group_name, lab_name, name, custom_headers).value!
  response.body unless response.nil?
end

#get_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

Get virtual machine.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 203

def get_resource_async(resource_group_name, lab_name, name, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = LabVirtualMachine.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Get virtual machine.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



188
189
190
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 188

def get_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil)
  get_resource_async(resource_group_name, lab_name, name, custom_headers).value!
end

#list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Array<LabVirtualMachine>

List virtual machines in a given lab.

operation. OData notation. will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



67
68
69
70
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 67

def list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  first_page = list_as_lazy(resource_group_name, lab_name, filter, top, order_by, custom_headers)
  first_page.get_all_items
end

#list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ ResponseWithContinuationLabVirtualMachine

List virtual machines in a given lab.

operation. OData notation. will be added to the HTTP request.

access to pages of the response.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • which provide lazy



41
42
43
44
45
46
47
48
49
50
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 41

def list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  response = list_async(resource_group_name, lab_name, filter, top, order_by, custom_headers).value!
  unless response.nil?
    page = response.body
    page.next_method = Proc.new do |next_link|
      list_next_async(next_link, custom_headers)
    end
    page
  end
end

#list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Concurrent::Promise

List virtual machines in a given lab.

operation. OData notation. to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 106

def list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name},
      query_params: {'$filter' => filter,'$top' => top,'$orderBy' => order_by,'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = ResponseWithContinuationLabVirtualMachine.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationLabVirtualMachine

List virtual machines in a given lab.

call to List operation. will be added to the HTTP request.

Parameters:

  • The NextLink from the previous successful

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



1074
1075
1076
1077
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 1074

def list_next(next_page_link, custom_headers = nil)
  response = list_next_async(next_page_link, custom_headers).value!
  response.body unless response.nil?
end

#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise

List virtual machines in a given lab.

call to List operation. to the HTTP request.

Parameters:

  • The NextLink from the previous successful

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 1103

def list_next_async(next_page_link, custom_headers = nil)
  fail ArgumentError, 'next_page_link is nil' if next_page_link.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '{nextLink}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      skip_encoding_path_params: {'nextLink' => next_page_link},
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :get, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = ResponseWithContinuationLabVirtualMachine.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List virtual machines in a given lab.

call to List operation. will be added to the HTTP request.

Parameters:

  • The NextLink from the previous successful

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



1089
1090
1091
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 1089

def list_next_with_http_info(next_page_link, custom_headers = nil)
  list_next_async(next_page_link, custom_headers).value!
end

#list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

List virtual machines in a given lab.

operation. OData notation. will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • (defaults to: nil)

    The filter to apply on the operation.

  • (defaults to: nil)

    The maximum number of resources to return from the

  • (defaults to: nil)

    The ordering expression for the results, using

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



87
88
89
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 87

def list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil)
  list_async(resource_group_name, lab_name, filter, top, order_by, custom_headers).value!
end

#patch_resource(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil) ⇒ LabVirtualMachine

Modify properties of virtual machines.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • operation results.



569
570
571
572
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 569

def patch_resource(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil)
  response = patch_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers).value!
  response.body unless response.nil?
end

#patch_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil) ⇒ Concurrent::Promise

Modify properties of virtual machines.

to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • hash of custom headers that will be added

Returns:

  • Promise object which holds the HTTP response.



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 602

def patch_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil)
  fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil?
  fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil?
  fail ArgumentError, 'lab_name is nil' if lab_name.nil?
  fail ArgumentError, 'name is nil' if name.nil?
  fail ArgumentError, 'lab_virtual_machine is nil' if lab_virtual_machine.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Serialize Request
  request_mapper = LabVirtualMachine.mapper()
  request_content = @client.serialize(request_mapper,  lab_virtual_machine, 'lab_virtual_machine')
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualmachines/{name}'
  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {})
  }

  request_url = @base_url || @client.base_url

  request = MsRest::HttpOperationRequest.new(request_url, path_template, :patch, options)
  promise = request.run_promise do |req|
    @client.credentials.sign_request(req) unless @client.credentials.nil?
  end

  promise = promise.then do |http_response|
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(request, http_response, error_model)
    end

    # Create Result
    result = MsRestAzure::AzureOperationResponse.new(request, http_response)
    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = LabVirtualMachine.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response, 'result.body')
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#patch_resource_with_http_info(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse

Modify properties of virtual machines.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • HTTP response information.



586
587
588
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 586

def patch_resource_with_http_info(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers = nil)
  patch_resource_async(resource_group_name, lab_name, name, lab_virtual_machine, custom_headers).value!
end

#start(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object

Start a Lab VM. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that



819
820
821
822
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 819

def start(resource_group_name, lab_name, name, custom_headers = nil)
  response = start_async(resource_group_name, lab_name, name, custom_headers).value!
  nil
end

#start_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

will be added to the HTTP request.

response.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • promise which provides async access to http



834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 834

def start_async(resource_group_name, lab_name, name, custom_headers = nil)
  # Send request
  promise = begin_start_async(resource_group_name, lab_name, name, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#stop(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object

Stop a Lab VM. This operation can take a while to complete.

will be added to the HTTP request.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that



946
947
948
949
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 946

def stop(resource_group_name, lab_name, name, custom_headers = nil)
  response = stop_async(resource_group_name, lab_name, name, custom_headers).value!
  nil
end

#stop_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise

will be added to the HTTP request.

response.

Parameters:

  • The name of the resource group.

  • The name of the lab.

  • The name of the virtual Machine.

  • (defaults to: nil)

    A hash of custom headers that

Returns:

  • promise which provides async access to http



961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_machine.rb', line 961

def stop_async(resource_group_name, lab_name, name, custom_headers = nil)
  # Send request
  promise = begin_stop_async(resource_group_name, lab_name, name, custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end