Class: Azure::ARM::DevTestLabs::VirtualNetworkOperations
- Inherits:
-
Object
- Object
- Azure::ARM::DevTestLabs::VirtualNetworkOperations
- Includes:
- Models, MsRestAzure
- Defined in:
- lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb
Overview
Azure DevTest Labs REST API.
Instance Attribute Summary collapse
-
#client ⇒ DevTestLabsClient
readonly
Reference to the DevTestLabsClient.
Instance Method Summary collapse
-
#begin_create_or_update_resource(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ VirtualNetwork
Create or replace an existing virtual network.
-
#begin_create_or_update_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ Concurrent::Promise
Create or replace an existing virtual network.
-
#begin_create_or_update_resource_with_http_info(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Create or replace an existing virtual network.
-
#begin_delete_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object
Delete virtual network.
-
#begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise
Delete virtual network.
-
#begin_delete_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Delete virtual network.
-
#create_or_update_resource(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ VirtualNetwork
Create or replace an existing virtual network.
-
#create_or_update_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ Concurrent::Promise
will be added to the HTTP request.
-
#delete_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object
Delete virtual network.
-
#delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise
will be added to the HTTP request.
-
#get_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ VirtualNetwork
Get virtual network.
-
#get_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise
Get virtual network.
-
#get_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Get virtual network.
-
#initialize(client) ⇒ VirtualNetworkOperations
constructor
Creates and initializes a new instance of the VirtualNetworkOperations class.
-
#list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Array<VirtualNetwork>
List virtual networks in a given lab.
-
#list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ ResponseWithContinuationVirtualNetwork
List virtual networks in a given lab.
-
#list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Concurrent::Promise
List virtual networks in a given lab.
-
#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationVirtualNetwork
List virtual networks in a given lab.
-
#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise
List virtual networks in a given lab.
-
#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List virtual networks in a given lab.
-
#list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List virtual networks in a given lab.
-
#patch_resource(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ VirtualNetwork
Modify properties of virtual networks.
-
#patch_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ Concurrent::Promise
Modify properties of virtual networks.
-
#patch_resource_with_http_info(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Modify properties of virtual networks.
Constructor Details
#initialize(client) ⇒ VirtualNetworkOperations
Creates and initializes a new instance of the VirtualNetworkOperations class.
18 19 20 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 18 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ DevTestLabsClient (readonly)
Returns reference to the DevTestLabsClient.
23 24 25 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 23 def client @client end |
Instance Method Details
#begin_create_or_update_resource(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ VirtualNetwork
Create or replace an existing virtual network. This operation can take a while to complete.
will be added to the HTTP request.
434 435 436 437 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 434 def begin_create_or_update_resource(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) response = begin_create_or_update_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers).value! response.body unless response.nil? end |
#begin_create_or_update_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ Concurrent::Promise
Create or replace an existing virtual network. This operation can take a while to complete.
to the HTTP request.
469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 469 def begin_create_or_update_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'lab_name is nil' if lab_name.nil? fail ArgumentError, 'name is nil' if name.nil? fail ArgumentError, 'virtual_network is nil' if virtual_network.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? request_headers['Content-Type'] = 'application/json; charset=utf-8' # Serialize Request request_mapper = VirtualNetwork.mapper() request_content = @client.serialize(request_mapper, virtual_network, 'virtual_network') request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualnetworks/{name}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:put, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 || status_code == 201 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = VirtualNetwork.mapper() result.body = @client.deserialize(result_mapper, parsed_response, 'result.body') rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end # Deserialize Response if status_code == 201 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = VirtualNetwork.mapper() result.body = @client.deserialize(result_mapper, parsed_response, 'result.body') rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#begin_create_or_update_resource_with_http_info(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Create or replace an existing virtual network. This operation can take a while to complete.
will be added to the HTTP request.
452 453 454 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 452 def begin_create_or_update_resource_with_http_info(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) begin_create_or_update_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers).value! end |
#begin_delete_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object
Delete virtual network. This operation can take a while to complete.
will be added to the HTTP request.
552 553 554 555 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 552 def begin_delete_resource(resource_group_name, lab_name, name, custom_headers = nil) response = begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers).value! nil end |
#begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise
Delete virtual network. This operation can take a while to complete.
to the HTTP request.
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 583 def begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'lab_name is nil' if lab_name.nil? fail ArgumentError, 'name is nil' if name.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualnetworks/{name}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:delete, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 202 || status_code == 204 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result end promise.execute end |
#begin_delete_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Delete virtual network. This operation can take a while to complete.
will be added to the HTTP request.
568 569 570 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 568 def begin_delete_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers).value! end |
#create_or_update_resource(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ VirtualNetwork
Create or replace an existing virtual network. This operation can take a while to complete.
will be added to the HTTP request.
239 240 241 242 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 239 def create_or_update_resource(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) response = create_or_update_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers).value! response.body unless response.nil? end |
#create_or_update_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ Concurrent::Promise
will be added to the HTTP request.
response.
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 255 def create_or_update_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) # Send request promise = begin_create_or_update_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers) promise = promise.then do |response| # Defining deserialization method. deserialize_method = lambda do |parsed_response| result_mapper = VirtualNetwork.mapper() parsed_response = @client.deserialize(result_mapper, parsed_response, 'parsed_response') end # Waiting for response. @client.get_long_running_operation_result(response, deserialize_method) end promise end |
#delete_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Object
Delete virtual network. This operation can take a while to complete.
will be added to the HTTP request.
282 283 284 285 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 282 def delete_resource(resource_group_name, lab_name, name, custom_headers = nil) response = delete_resource_async(resource_group_name, lab_name, name, custom_headers).value! nil end |
#delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise
will be added to the HTTP request.
response.
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 297 def delete_resource_async(resource_group_name, lab_name, name, custom_headers = nil) # Send request promise = begin_delete_resource_async(resource_group_name, lab_name, name, custom_headers) promise = promise.then do |response| # Defining deserialization method. deserialize_method = lambda do |parsed_response| end # Waiting for response. @client.get_long_running_operation_result(response, deserialize_method) end promise end |
#get_resource(resource_group_name, lab_name, name, custom_headers = nil) ⇒ VirtualNetwork
Get virtual network.
will be added to the HTTP request.
142 143 144 145 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 142 def get_resource(resource_group_name, lab_name, name, custom_headers = nil) response = get_resource_async(resource_group_name, lab_name, name, custom_headers).value! response.body unless response.nil? end |
#get_resource_async(resource_group_name, lab_name, name, custom_headers = nil) ⇒ Concurrent::Promise
Get virtual network.
to the HTTP request.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 173 def get_resource_async(resource_group_name, lab_name, name, custom_headers = nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'lab_name is nil' if lab_name.nil? fail ArgumentError, 'name is nil' if name.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualnetworks/{name}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = VirtualNetwork.mapper() result.body = @client.deserialize(result_mapper, parsed_response, 'result.body') rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Get virtual network.
will be added to the HTTP request.
158 159 160 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 158 def get_resource_with_http_info(resource_group_name, lab_name, name, custom_headers = nil) get_resource_async(resource_group_name, lab_name, name, custom_headers).value! end |
#list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Array<VirtualNetwork>
List virtual networks in a given lab.
operation. notation. will be added to the HTTP request.
40 41 42 43 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 40 def list(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) first_page = list_as_lazy(resource_group_name, lab_name, filter, top, order_by, custom_headers) first_page.get_all_items end |
#list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ ResponseWithContinuationVirtualNetwork
List virtual networks in a given lab.
operation. notation. will be added to the HTTP request.
pages of the response.
729 730 731 732 733 734 735 736 737 738 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 729 def list_as_lazy(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) response = list_async(resource_group_name, lab_name, filter, top, order_by, custom_headers).value! unless response.nil? page = response.body page.next_method = Proc.new do |next_page_link| list_next_async(next_page_link, custom_headers) end page end end |
#list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ Concurrent::Promise
List virtual networks in a given lab.
operation. notation. to the HTTP request.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 79 def list_async(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'lab_name is nil' if lab_name.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualnetworks' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name}, query_params: {'$filter' => filter,'$top' => top,'$orderBy' => order_by,'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = ResponseWithContinuationVirtualNetwork.mapper() result.body = @client.deserialize(result_mapper, parsed_response, 'result.body') rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_next(next_page_link, custom_headers = nil) ⇒ ResponseWithContinuationVirtualNetwork
List virtual networks in a given lab.
to List operation. will be added to the HTTP request.
636 637 638 639 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 636 def list_next(next_page_link, custom_headers = nil) response = list_next_async(next_page_link, custom_headers).value! response.body unless response.nil? end |
#list_next_async(next_page_link, custom_headers = nil) ⇒ Concurrent::Promise
List virtual networks in a given lab.
to List operation. to the HTTP request.
665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 665 def list_next_async(next_page_link, custom_headers = nil) fail ArgumentError, 'next_page_link is nil' if next_page_link.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = '{nextLink}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], skip_encoding_path_params: {'nextLink' => next_page_link}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = ResponseWithContinuationVirtualNetwork.mapper() result.body = @client.deserialize(result_mapper, parsed_response, 'result.body') rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_next_with_http_info(next_page_link, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List virtual networks in a given lab.
to List operation. will be added to the HTTP request.
651 652 653 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 651 def list_next_with_http_info(next_page_link, custom_headers = nil) list_next_async(next_page_link, custom_headers).value! end |
#list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
List virtual networks in a given lab.
operation. notation. will be added to the HTTP request.
60 61 62 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 60 def list_with_http_info(resource_group_name, lab_name, filter = nil, top = nil, order_by = nil, custom_headers = nil) list_async(resource_group_name, lab_name, filter, top, order_by, custom_headers).value! end |
#patch_resource(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ VirtualNetwork
Modify properties of virtual networks.
will be added to the HTTP request.
325 326 327 328 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 325 def patch_resource(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) response = patch_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers).value! response.body unless response.nil? end |
#patch_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ Concurrent::Promise
Modify properties of virtual networks.
to the HTTP request.
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 358 def patch_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) fail ArgumentError, '@client.subscription_id is nil' if @client.subscription_id.nil? fail ArgumentError, 'resource_group_name is nil' if resource_group_name.nil? fail ArgumentError, 'lab_name is nil' if lab_name.nil? fail ArgumentError, 'name is nil' if name.nil? fail ArgumentError, 'virtual_network is nil' if virtual_network.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? request_headers['Content-Type'] = 'application/json; charset=utf-8' # Serialize Request request_mapper = VirtualNetwork.mapper() request_content = @client.serialize(request_mapper, virtual_network, 'virtual_network') request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil path_template = '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DevTestLab/labs/{labName}/virtualnetworks/{name}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'subscriptionId' => @client.subscription_id,'resourceGroupName' => resource_group_name,'labName' => lab_name,'name' => name}, query_params: {'api-version' => @client.api_version}, body: request_content, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:patch, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = VirtualNetwork.mapper() result.body = @client.deserialize(result_mapper, parsed_response, 'result.body') rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#patch_resource_with_http_info(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) ⇒ MsRestAzure::AzureOperationResponse
Modify properties of virtual networks.
will be added to the HTTP request.
342 343 344 |
# File 'lib/generated/azure_mgmt_devtestlabs/virtual_network_operations.rb', line 342 def patch_resource_with_http_info(resource_group_name, lab_name, name, virtual_network, custom_headers = nil) patch_resource_async(resource_group_name, lab_name, name, virtual_network, custom_headers).value! end |